<?php

namespace App\Console\Commands;

use DB;
use App\Fee;
use App\User;
use App\Betting;
use App\GameResult;
use App\Transaction;
use App\FeeTransaction;
use App\Events\GameResult as EventGameResult;
use Cron\CronExpression;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Http;

class RunGame extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'game:run {symbol} {minutes}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Running game';

    protected $realize_price = [
        'BTCUSDT' => [
            '1' => 1,
            '3' => 3,
            '5' => 5,
        ],
        'GBPAUD' => [
            '1' => 0.0001,
            '3' => 0.0003,
            '5' => 0.0005,
        ],
    ];

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $symbol = $this->argument('symbol');
        if (!in_array($symbol, ['BTCUSDT', 'GBPAUD'])) {
            return;
        }

        $minutes = $this->argument('minutes');
        $startTime = (new Carbon(CronExpression::factory('*/'.$minutes.' * * * *')->getPreviousRunDate('now', 1, true)))->format('Y-m-d H:i:s');

        $pad_sec = $minutes * 60;
        $round = date('ymd', time() - $pad_sec).str_pad(ceil((Carbon::now()->diffInSeconds((new Carbon('-'.$pad_sec.' seconds'))->startOfDay())) / $pad_sec) - 1, 4, '0', STR_PAD_LEFT);

        sleep(5);

        if ($symbol == 'BTCUSDT') {
            $ticker = Http::get('https://api.binance.com/api/v3/klines?symbol=BTCUSDT&interval=1m&limit=6')->json();

            if ($minutes == 1) {
                $open = $ticker[4][1];
                $close = $ticker[4][4];
            } else if ($minutes == 3) {
                $open = $ticker[2][1];
                $close = $ticker[4][4];
            } else if ($minutes == 5) {
                $open = $ticker[0][1];
                $close = $ticker[4][4];
            } else {
                return;
            }
        } else if ($symbol == 'GBPAUD') {
            $tick_data =
                DB::query()->select(
                    't.time',
                    DB::raw('(SELECT t2.price FROM tick_data AS t2 WHERE t2.id = t.o_id) AS o'),
                    't.h',
                    't.l',
                    DB::raw('(SELECT t2.price FROM tick_data AS t2 WHERE t2.id = t.c_id) AS c')
                )
                ->fromSub(function ($query) use ($startTime, $minutes) {
                    $query->select(
                        DB::raw('FROM_UNIXTIME('.$minutes.' * 60 * (UNIX_TIMESTAMP(created_at) DIV ('.$minutes.' * 60))) AS time'),
                        DB::raw('MIN(id) AS o_id'),
                        DB::raw('MAX(price) AS h'),
                        DB::raw('MIN(price) AS l'),
                        DB::raw('MAX(id) AS c_id')
                    );
                    $query->from('tick_data');
                    $query->where('created_at', '>=', (new Carbon($startTime))->format('Y-m-d H:i:s'));
                    $query->where('created_at', '<', (new Carbon($startTime))->addMinutes($minutes)->format('Y-m-d H:i:s'));
                    $query->groupBy('time');
                }, 't')
                ->groupBy('t.time')
                ->first();

            $open = $tick_data->o;
            $close = $tick_data->c;
        }

        if (bccomp(ltrim(bcsub($open, $close, 8), '-'), $this->realize_price[$symbol][$minutes], 8) == -1) {
            $result = 'unrealized';
        } else {
            if (bccomp($open, $close, 8) == -1) { // up
                $result = 'up';
            } else {
                $result = 'down';
            }
        }

        event(new EventGameResult($symbol, $minutes, $round, $result));

        $gameResult = new GameResult;
        $gameResult->symbol = $symbol;
        $gameResult->type = $minutes;
        $gameResult->round =  $round;
        $gameResult->result =  $result;
        $gameResult->open = $open;
        $gameResult->close =  $close;

        $gameResult->save();

        if ($result == 'unrealized') {
            $bettings = Betting::whereSymbol($symbol)->whereType($minutes)->whereNull('result')->whereRound($round)->cursor();
            foreach ($bettings as $betting) {
                $user = $betting->user;

                $betting->result = 'unrealized';

                $amount = bcmul($betting->amount, 10000); // 1.00x (return)

                $tx = new Transaction;

                $tx->user_id = $user->id;
                $tx->type = 'deposit_game_unrealized';
                $tx->amount = $amount;
                $tx->info = 'Betting id: '.$betting->id;
                $tx->status = 'success';

                $tx->save();

                $user->increment('balance', $tx->amount);

                $betting->user_balance = $user->balance;
                $betting->save();
            }
        } else {
            $correct_bettings = Betting::whereSymbol($symbol)->whereType($minutes)->whereNull('result')->wherePick($result)->whereRound($round)->cursor();
            foreach ($correct_bettings as $betting) {
                $user = $betting->user;

                $betting->result = 'correct';

                $amount = bcmul(bcmul($betting->amount, 10000), $betting->rate, 2); // 1.90x

                $tx = new Transaction;

                $tx->user_id = $user->id;
                $tx->type = 'deposit_game_correct';
                $tx->amount = $amount;
                $tx->info = 'Betting id: '.$betting->id;
                $tx->status = 'success';

                $tx->save();

                $user->increment('balance', $tx->amount);

                $betting->user_balance = $user->balance;
                $betting->save();

                $this->processFee($user, $betting->amount);
            }

            $incorrect_bettings = Betting::whereSymbol($symbol)->whereType($minutes)->whereNull('result')->where('pick', '!=', $result)->whereRound($round)->cursor();
            foreach ($incorrect_bettings as $betting) {
                $user = $betting->user;

                $betting->result = 'incorrect';
                $betting->user_balance = $user->balance;
                $betting->save();
            }
        }

        return 0;
    }

    // 1.90x (10%) fee
    public function processFee($user, $amount)
    {
        $fee_previous = 0;
        $amount = bcmul($amount, 10000);

        $parent_branch = $user->parentBranch;

        while($parent_branch) {
            $branch_user = $parent_branch->branchUser;
            $branch_fee = bcsub($branch_user->fee_percent, $fee_previous, 2);
            $fee_previous = $branch_user->fee_percent;

            if ($branch_fee <= 0) {
                return;
            }

            $fee = new Fee;

            $fee->user_id = $user->id;
            $fee->branch_user_id = $branch_user->id;
            $fee->amount = bcmul($amount, bcdiv($branch_fee, 100, 4));
            $fee->fee_percent = $branch_fee;

            $fee->save();

            $branch_user->increment('fee_balance', $fee->amount);

            $parent_branch = $branch_user->parentBranch;
        }
    }
}
