<?php

namespace App\Console\Commands;

use App\Fee;
use App\User;
use App\Betting;
use App\GameResult;
use App\Transaction;
use App\FeeTransaction;
use App\Events\GameResult as EventGameResult;
use Cron\CronExpression;
use Carbon\Carbon;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Http;

class RunGameManual extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'game:manualrun {symbol} {minutes} {round} {open} {close}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Running game manually';

    protected $realize_price = [
        'BTCUSDT' => [
            '1' => 1,
            '3' => 3,
            '5' => 5,
        ],
        'GBPAUD' => [
            '1' => 0.0001,
            '3' => 0.0003,
            '5' => 0.0005,
        ],
    ];

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $symbol = $this->argument('symbol');

        $minutes = $this->argument('minutes');

        $round = $this->argument('round');

        $open = $this->argument('open');
        $close = $this->argument('close');

        if (bccomp(ltrim(bcsub($open, $close, 8), '-'), $this->realize_price[$symbol][$minutes], 8) == -1) {
            $result = 'unrealized';
        } else {
            if (bccomp($open, $close, 8) == -1) { // up
                $result = 'up';
            } else {
                $result = 'down';
            }
        }

        event(new EventGameResult($symbol, $minutes, $round, $result));

        $gameResult = new GameResult;
        $gameResult->symbol = $symbol;
        $gameResult->type = $minutes;
        $gameResult->round = $round;
        $gameResult->result = $result;
        $gameResult->open = $open;
        $gameResult->close = $close;
        $gameResult->manual_insert = true;

        $gameResult->save();

        if ($result == 'unrealized') {
            $bettings = Betting::whereSymbol($symbol)->whereType($minutes)->whereNull('result')->whereRound($round)->cursor();
            foreach ($bettings as $betting) {
                $user = $betting->user;

                $betting->result = 'unrealized';

                $amount = bcmul($betting->amount, 10000); // 1.00x (return)

                $tx = new Transaction;

                $tx->user_id = $user->id;
                $tx->type = 'deposit_game_unrealized';
                $tx->amount = $amount;
                $tx->info = 'Betting id: '.$betting->id;
                $tx->status = 'success';

                $tx->save();

                $user->increment('balance', $tx->amount);

                $betting->user_balance = $user->balance;
                $betting->save();
            }
        } else {
            $correct_bettings = Betting::whereSymbol($symbol)->whereType($minutes)->whereNull('result')->wherePick($result)->whereRound($round)->cursor();
            foreach ($correct_bettings as $betting) {
                $user = $betting->user;

                $betting->result = 'correct';

                $amount = bcmul(bcmul($betting->amount, 10000), $betting->rate, 2); // 1.90x

                $tx = new Transaction;

                $tx->user_id = $user->id;
                $tx->type = 'deposit_game_correct';
                $tx->amount = $amount;
                $tx->info = 'Betting id: '.$betting->id;
                $tx->status = 'success';

                $tx->save();

                $user->increment('balance', $tx->amount);

                $betting->user_balance = $user->balance;
                $betting->save();

                $this->processFee($user, $betting->amount);
            }

            $incorrect_bettings = Betting::whereSymbol($symbol)->whereType($minutes)->whereNull('result')->where('pick', '!=', $result)->whereRound($round)->cursor();
            foreach ($incorrect_bettings as $betting) {
                $user = $betting->user;

                $betting->result = 'incorrect';
                $betting->user_balance = $user->balance;
                $betting->save();
            }
        }

        return 0;
    }

    // 1.90x (10%) fee
    public function processFee($user, $amount)
    {
        $fee_previous = 0;
        $amount = bcmul($amount, 10000);

        $parent_branch = $user->parentBranch;

        while($parent_branch) {
            $branch_user = $parent_branch->branchUser;
            $branch_fee = bcsub($branch_user->fee_percent, $fee_previous, 2);
            $fee_previous = $branch_user->fee_percent;

            if ($branch_fee <= 0) {
                return;
            }

            $fee = new Fee;

            $fee->user_id = $user->id;
            $fee->branch_user_id = $branch_user->id;
            $fee->amount = bcmul($amount, bcdiv($branch_fee, 100, 4));
            $fee->fee_percent = $branch_fee;

            $fee->save();

            $branch_user->increment('fee_balance', $fee->amount);

            $parent_branch = $branch_user->parentBranch;
        }
    }
}
