<?php

namespace App\Http\Controllers\Auth;

use App\User;
use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

class ChangePasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Change Password Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    protected function showChangeForm()
    {
        return view('auth.passwords.change');
    }

    protected function changePassword(Request $request)
    {
        $request->validate([
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);

        if(Auth::once(['account' => Auth::user()->account, 'password' => $request->password_old])) {
            Auth::user()->forceFill([
                'password' => Hash::make($request->password),
            ])->save();

            $request->session()->flash('message', '비밀번호가 변경되었습니다');

            return redirect()->route('main');
        } else {
            return redirect()->back()->withErrors(['message' => '기존 비밀번호가 일치하지 않습니다'], 'old');
        }
    }
}