<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\User;
use App\Branch;
use Illuminate\Http\Request;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'account' => ['required', 'string', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
            'name' => ['required', 'string', 'max:16', 'unique:users'],
            'phone' => ['required', 'string', 'max:16'],
            'bank_owner' => ['required', 'string', 'max:16'],
            'bank_name' => ['required', 'string', 'max:16', 'not_in:선택'],
            'bank_address' => ['required', 'string'],
            'email' => ['required', 'email'],
            'branch' => [
                'required',
                'string',
                Rule::exists('users', 'name')->where(function ($query) {
                    $query->where('user_type', '!=', 'user');
                    $query->where('status', '=', 'normal');
                })
            ],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        return User::create([
            'account' => $data['account'],
            'password' => Hash::make($data['password']),
            'name' => $data['name'],
            'bank_info' => "{$data['bank_name']} / {$data['bank_address']} / {$data['bank_owner']} / {$data['phone']}",
            'email' => $data['email'],
        ]);
    }

    /**
     * The user has been registered.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  mixed  $user
     * @return mixed
     */
    protected function registered(Request $request, $user)
    {
        try {
            $branch_user = User::where('name', $request->branch)->where('user_type', '!=', 'user')->firstOrFail();

            Branch::create([
                'user_id' => $user->id,
                'branch_user_id' => $branch_user->id,
            ]);
        } catch (ModelNotFoundException $e) {}
    }
}
