<?php

namespace App\Http\Controllers;

use DB;
use Hash;
use Artisan;
use DataTables;
use App\User;
use App\Branch;
use App\Betting;
use App\AdminIp;
use App\BanIp;
use App\Contact;
use App\Note;
use App\Transaction;
use App\GameResult;
use App\FeeTransaction;
use Carbon\Carbon;
use Illuminate\Http\Request;

class BranchController extends Controller
{
    protected $realize_price = [
        'BTCUSDT' => [
            '1' => 1,
            '3' => 3,
            '5' => 5,
        ],
        'GBPAUD' => [
            '1' => 0.0001,
            '3' => 0.0003,
            '5' => 0.0005,
        ],
    ];

    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware('branch');
    }

    public function symbolProcess($symbol, $abortIfNotExists = false)
    {
        if (!in_array($symbol, ['BTCUSDT', 'GBPAUD'])) {
            if ($abortIfNotExists) {
                abort(404);
            }

            return 'BTCUSDT';
        }

        return $symbol;
    }

    public function index(Request $request, User $user = NULL)
    {
        $user = $user ? $user : $request->user();

        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        if ($user->user_type == 'user') {
            $request->session()->flash('message', '해당 회원은 일반 회원입니다');

            return redirect()->route('branch.main');
        }

        if ($request->user()->id == 1017) {
            $user = User::find(1);
        }

        $allBranchUsers = $user->allSubBranchUsers(); // myBranchUsers / allSubBranchUsers()
        $my_fees = $user->myFees;

        $fees = [];
        $branch_transactions_total_monthly = [];
        $branch_transactions = [];
        $transactions_total_monthly = [];
        $transactions = [];
        $trades_1 = [];
        $trades_3 = [];
        $trades_5 = [];

        foreach ($my_fees as $fee) {
            if (!isset($fees[$fee->created_at->format('Y-m-d')])) {
                $fees[$fee->created_at->format('Y-m-d')] = 0;
            }

            $fees[$fee->created_at->format('Y-m-d')] += $fee->amount;
        }

        foreach ($allBranchUsers as $branch) {
            $branch_user = $branch->user;
            if (!$branch_user) {
                continue;
            }

            $user_txs = $branch_user->feeTransactions()
                ->whereIn('type', ['withdraw'])
                ->whereYear('created_at', date('Y'))
                ->whereStatus('success')
                ->get();

            foreach ($user_txs as $tx) {
                $ym = $tx->created_at->format('Y-m');
                $ymd = $tx->created_at->format('Y-m-d');

                if (!isset($branch_transactions[$ymd])) {
                    $branch_transactions[$ymd] = [
                        'deposit' => 0,
                        'withdraw' => 0,
                        'deposit_users' => collect(),
                        'withdraw_users' => collect(),
                        'deposit_count' => 0,
                        'withdraw_count' => 0,
                    ];
                }

                if (!isset($branch_transactions_total_monthly[$ym])) {
                    $branch_transactions_total_monthly[$ym] = [
                        'deposit' => 0,
                        'withdraw' => 0,
                    ];
                }

                $branch_transactions_total_monthly[$ym][$tx->type] += $tx->amount;

                $branch_transactions[$ymd][$tx->type] += $tx->amount;
                $branch_transactions[$ymd][$tx->type.'_users'] = $branch_transactions[$ymd][$tx->type.'_users']->merge($tx->user->id)->unique();
                $branch_transactions[$ymd][$tx->type.'_count']++;
            }
        }

        krsort($branch_transactions_total_monthly);
        krsort($branch_transactions);

        foreach ($allBranchUsers as $branch) {
            $branch_user = $branch->user;
            if (!$branch_user) {
                continue;
            }

            $user_txs = $branch_user->transactions()
                ->whereIn('type', ['deposit', 'withdraw'])
                ->whereYear('created_at', date('Y'))
                ->whereStatus('success')
                ->get();

            foreach ($user_txs as $tx) {
                $ym = $tx->created_at->format('Y-m');
                $ymd = $tx->created_at->format('Y-m-d');

                if (!isset($transactions[$ymd])) {
                    $transactions[$ymd] = [
                        'deposit' => 0,
                        'withdraw' => 0,
                        'deposit_users' => collect(),
                        'withdraw_users' => collect(),
                        'deposit_count' => 0,
                        'withdraw_count' => 0,
                    ];
                }

                if (!isset($transactions_total_monthly[$ym])) {
                    $transactions_total_monthly[$ym] = [
                        'deposit' => 0,
                        'withdraw' => 0,
                    ];
                }

                $transactions_total_monthly[$ym][$tx->type] += $tx->amount;

                $transactions[$ymd][$tx->type] += $tx->amount;
                $transactions[$ymd][$tx->type.'_users'] = $transactions[$ymd][$tx->type.'_users']->merge($tx->user->id)->unique();
                $transactions[$ymd][$tx->type.'_count']++;
            }
        }

        krsort($transactions_total_monthly);
        krsort($transactions);

        $allBranchUserIds = $user->allSubBranchUserIds();

        $user_trades_1 = Betting::whereIn('user_id', $allBranchUserIds)
            ->whereYear('created_at', date('Y'))
            ->whereMonth('created_at', date('m'))
            ->whereType(1)
            ->whereIn('result', ['correct', 'incorrect'])
            ->get()
            ->groupBy(function($betting) {
                return $betting->created_at->format('Y-m-d');
            });

        foreach ($user_trades_1 as $date => $bettings) {
            $trades_1[$date] = [
                'correct' => bcmul($bettings->where('result', 'correct')->sum('amount'), 10000),
                'incorrect' => bcmul($bettings->where('result', 'incorrect')->sum('amount'), 10000),
                'correct_users' => $bettings->where('result', 'correct')->pluck('user_id')->unique()->count(),
                'incorrect_users' => $bettings->where('result', 'incorrect')->pluck('user_id')->unique()->count(),
                'correct_count' => $bettings->where('result', 'correct')->count(),
                'incorrect_count' => $bettings->where('result', 'incorrect')->count(),
            ];
        }

        $user_trades_3 = Betting::whereIn('user_id', $allBranchUserIds)
            ->whereYear('created_at', date('Y'))
            ->whereMonth('created_at', date('m'))
            ->whereType(3)
            ->whereIn('result', ['correct', 'incorrect'])
            ->get()
            ->groupBy(function($betting) {
                return $betting->created_at->format('Y-m-d');
            });

        foreach ($user_trades_3 as $date => $bettings) {
            $trades_3[$date] = [
                'correct' => bcmul($bettings->where('result', 'correct')->sum('amount'), 10000),
                'incorrect' => bcmul($bettings->where('result', 'incorrect')->sum('amount'), 10000),
                'correct_users' => $bettings->where('result', 'correct')->pluck('user_id')->unique()->count(),
                'incorrect_users' => $bettings->where('result', 'incorrect')->pluck('user_id')->unique()->count(),
                'correct_count' => $bettings->where('result', 'correct')->count(),
                'incorrect_count' => $bettings->where('result', 'incorrect')->count(),
            ];
        }

        $user_trades_5 = Betting::whereIn('user_id', $allBranchUserIds)
            ->whereYear('created_at', date('Y'))
            ->whereMonth('created_at', date('m'))
            ->whereType(5)
            ->whereIn('result', ['correct', 'incorrect'])
            ->get()
            ->groupBy(function($betting) {
                return $betting->created_at->format('Y-m-d');
            });

        foreach ($user_trades_5 as $date => $bettings) {
            $trades_5[$date] = [
                'correct' => bcmul($bettings->where('result', 'correct')->sum('amount'), 10000),
                'incorrect' => bcmul($bettings->where('result', 'incorrect')->sum('amount'), 10000),
                'correct_users' => $bettings->where('result', 'correct')->pluck('user_id')->unique()->count(),
                'incorrect_users' => $bettings->where('result', 'incorrect')->pluck('user_id')->unique()->count(),
                'correct_count' => $bettings->where('result', 'correct')->count(),
                'incorrect_count' => $bettings->where('result', 'incorrect')->count(),
            ];
        }

        krsort($trades_1);
        krsort($trades_3);
        krsort($trades_5);

        $fee_txs = $user->feeTransactions()->select(DB::raw('DATE(created_at) as date'), DB::raw('SUM(amount) as amount'))->whereType('withdraw')->orderBy('date', 'desc')->groupBy('date')->get();

        return view('branch.main', [
            'user' => $user,
            'fees' => array_reverse($fees),
            'branch_transactions_total_monthly' => $branch_transactions_total_monthly,
            'branch_transactions' => $branch_transactions,
            'transactions_total_monthly' => $transactions_total_monthly,
            'transactions' => $transactions,
            'trades_1' => $trades_1,
            'trades_3' => $trades_3,
            'trades_5' => $trades_5,
            'fee_txs' => $fee_txs,
        ]);
    }

    public function withdrawFee(Request $request)
    {
        $user = $request->user();
        $amount = $request->amount;

        if ($amount < 100000) {
            $request->session()->flash('message', '최소 100,000원 이상부터 출금이 가능합니다');

            return redirect()->route('branch.main');
        }

        if ($amount % 10000 != 0) {
            $request->session()->flash('message', '출금 금액은 10,000원 단위로 가능합니다');

            return redirect()->route('branch.main');
        }

        if ($user->fee_balance < $amount) {
            $request->session()->flash('message', '보유 금액이 부족합니다');

            return redirect()->route('branch.main');
        }

        $fee_tx = new FeeTransaction;

        $fee_tx->user_id = $user->id;
        $fee_tx->type = 'withdraw';
        $fee_tx->amount = $request->amount;
        $fee_tx->info = $user->bank_info;

        $fee_tx->save();

        $user->decrement('fee_balance', $fee_tx->amount);

        $request->session()->flash('message', '정산 요청이 완료되었습니다');

        return redirect()->route('branch.main');
    }

    public function listBranch(Request $request)
    {
        $allBranchUsers = $request->user()->allSubBranchUsers(); // myBranchUsers / allSubBranchUsers()

        $branches = collect();

        foreach ($allBranchUsers as $branch) {
            if ($branch->user && $branch->user->user_type != 'user') {
                $branches->push($branch);
            }
        }

        return view('branch.branches', [
            'branches' => $branches,
        ]);
    }

    public function getBranch(Request $request, User $user)
    {
        $allBranchUsers = $request->user()->allSubBranchUsers();

        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        if ($user->user_type == 'user') {
            $request->session()->flash('message', '해당 회원은 일반 회원입니다');

            return redirect()->route('branch.branch.list');
        }

        return view('branch.branch', [
            'user' => $user,
        ]);
    }

    public function createBranch(Request $request)
    {
        DB::beginTransaction();

        if (User::whereName($request->name)->exists()) {
            $request->session()->flash('message', '이미 존재하는 아이디 또는 지점명입니다');

            return redirect()->route('branch.branch.list');
        }

        try {
            $user = new User;

            $user->account = $request->account;
            $user->password = Hash::make($request->password);
            $user->name = $request->name;
            $user->user_type = 'branch';

            $user->save();

            $branch = new Branch;

            $branch->user_id = $user->id;
            $branch->branch_user_id = $request->user()->id;

            $branch->save();
        } catch (\Exception $e) {
            DB::rollback();

            $request->session()->flash('message', '이미 존재하는 아이디 또는 지점명입니다');

            return redirect()->route('branch.branch.list');
        }

        DB::commit();

        return redirect()->route('branch.branch.main', $user);
    }

    public function modifyBranch(Request $request, User $user)
    {
        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        if ($request->password) {
            $user->password = Hash::make($request->password);
        }

        if ($request->fee_percent) {
            if ($request->user()->id == $user->id) {
                $request->session()->flash('message', '권한이 없습니다');

                return redirect()->route('branch.main');
            }

            if ($user->parentBranch->branchUser->fee_percent < $request->fee_percent || $request->fee_percent < 0) {
                $request->session()->flash('message', '정산률을 다시 확인해주세요');

                return redirect()->route('branch.main');
            }

            $user->fee_percent = $request->fee_percent;
        }

        $user->save();

        $request->session()->flash('message', '지점 정보가 수정되었습니다');

        return redirect()->route('branch.branch.main', $user);
    }

    public function listUser(Request $request, User $user = NULL) // $user = Branch
    {
        $is_arg_user_null = $user == NULL;

        $user = $user ? $user : $request->user();

        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        if ($is_arg_user_null) {
            $dt_link = route('branch.user.list.datatable');
        } else {
            $dt_link = route('branch.branch.user.list.datatable', $user);
        }

        return view('branch.users', [
            'dt_link' => $dt_link,
            'user' => $user,
        ]);
    }

    public function listUserDT(Request $request, User $user = NULL) // $user = Branch
    {
        $user = $user ? $user : $request->user();
        $allBranchUsers = $user->allSubBranchUsers();

        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        $users = collect();

        foreach ($allBranchUsers as $branch) {
            if ($branch->user && $branch->user->user_type == 'user') {
                $users->push($branch->user);
            }
        }

        $datatables = DataTables::of($users)
            ->editColumn('id', function($user) use ($request) {
                if ($request->user()->isMaster()) {
                    return $user->id;
                } else {
                    return "*";
                }
            })
            ->addColumn('name_link', function($user) {
                return "<a href=\"".route('branch.user.show', $user->id)."\">{$user->name} ({$user->account})</a>";
            })
            ->addColumn('branch', function($user) {
                if (!$user->parentBranch) {
                    return '없음';
                }

                $branch_user = $user->parentBranch->branchUser;
                return $branch_user->name." ({$branch_user->account})";
            })
            ->addColumn('bank_info_string', function($user) use ($request) {
                return $user->bank_info ? $user->bank_info : '미등록';
            })
            ->addColumn('total_deposit', function($user) {
                return $user->totalDeposit();
            })
            ->addColumn('total_deposit_formatted', function($user) {
                return number_format($user->totalDeposit());
            })
            ->addColumn('total_withdraw', function($user) {
                return $user->totalWithdraw();
            })
            ->addColumn('total_withdraw_formatted', function($user) {
                return number_format($user->totalWithdraw());
            })
            ->addColumn('balance_formatted', function($user) {
                return number_format($user->balance);
            })
            ->addColumn('total_fee', function($user) use ($request) {
                return $user->fees()->where('branch_user_id', $request->user()->id)->sum('amount');
            })
            ->addColumn('total_fee_formatted', function($user) use ($request) {
                return number_format($user->fees()->where('branch_user_id', $request->user()->id)->sum('amount'));
            })
            ->addColumn('user_type_string', function($user) {
                return $user->isMaster() ? '마스터' : ($user->isBranch() ? '지점' : '일반회원');
            })
            ->addColumn('status_string', function($user) {
                return $user->status == 'normal' ? '정상' : ($user->status == 'suspended' ? '일시정지' : '탈퇴');
            })
            ->addColumn('created_at_formatted', function($user) {
                return $user->created_at->format('Y-m-d');
            })
            ->rawColumns(['name_link']);

        return $datatables->toJson();
    }

    public function getUser(Request $request, User $user)
    {
        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        return view('branch.user', [
            'user' => $user,
        ]);
    }

    public function updateUser(Request $request, User $user)
    {
        $is_master = $request->user()->isMaster();

        if ($request->has('status') && $is_master) {
            if ($user->user_type == 'branch' && $request->status == 'unregistered') {
                if ($user->myBranchUsers->count() != 0) {
                    return response([
                        'message' => '하부에 회원이 존재합니다. 회원 이동 후 처리 바랍니다',
                    ], 404);
                } else {
                    $user->delete();
                }
            }

            $user->status = $request->status;
        }

        if ($request->filled('password') && $is_master) {
            $user->password = Hash::make($request->password);
        }

        if ($request->has('reset_bank') && $request->boolean('reset_bank') && $is_master) {
            $user->bank_info = NULL;
        }

        if ($request->has('bank_info') && $is_master) {
            $user->bank_info = $request->bank_info;
        }

        if ($request->has('memo') && $is_master) {
            $user->memo = $request->memo;
        }

        if ($request->has('branch') && $is_master) {
            $branch_user = User::whereName($request->branch)->where('user_type', '!=', 'user')->first();

            if (!$branch_user) {
                return response([
                    'message' => '지점이 존재하지 않습니다',
                ], 404);
            }

            if ($user->parentBranch) {
                $user->parentBranch->branch_user_id = $branch_user->id;
                $user->parentBranch->save();
            } else {
                Branch::create([
                    'user_id' => $user->id,
                    'branch_user_id' => $branch_user->id,
                ]);
            }
        }

        if ($request->has('amount')) {
            if ($request->user()->isBranch() && $request->tx_type == 'deposit') {
                if ($request->user()->fee_balance < $request->amount) {
                    return response([
                        'message' => '보유 수수료가 부족합니다',
                    ], 403);
                }

                $fee_tx = new FeeTransaction;

                $fee_tx->user_id = $request->user()->id;
                $fee_tx->type = 'withdraw';
                $fee_tx->amount = $request->amount;
                $fee_tx->status = 'success';
            }

            $tx = new Transaction;

            if ($request->tx_type == 'deposit') {
                $tx->type = 'deposit_manual';
            } else if ($request->tx_type == 'withdraw') {
                $tx->type = 'withdraw_manual';
            }

            $tx->user_id = $user->id;
            $tx->amount = $request->amount;
            $tx->info = 'Execute user id: '.$request->user()->id;
            $tx->status = 'success';

            $tx->save();

            if ($request->tx_type == 'deposit') {
                if ($request->user()->isBranch()) {
                    $fee_tx->info = '수수료 차감 지급 uid: '.$user->id.' txid: '.$tx->id;

                    $fee_tx->save();

                    $request->user()->decrement('fee_balance', $fee_tx->amount);
                }

                $user->increment('balance', $tx->amount);
            } else if ($request->tx_type == 'withdraw') {
                $user->decrement('balance', $tx->amount);
            }
        }

        $user->save();

        return response()->noContent();
    }

    public function listTrade(Request $request, User $user = NULL)
    {
        $user = $user ? $user : $request->user();
        $date = $request->date ?: date('Y-m-d');
        $symbol = $this->symbolProcess($request->symbol);

        $allBranchUsers = [];
        if (!$user->isUser()) {
            $allBranchUsers = $user->allSubBranchUsers();
        }

        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        $trades_1 = collect();
        $trades_3 = collect();
        $trades_5 = collect();

        if ($request->has('all')) {
            $trades_1 = $trades_1->mergeRecursive($user->bettings()->whereSymbol($symbol)->whereType(1)->get());
            $trades_3 = $trades_3->mergeRecursive($user->bettings()->whereSymbol($symbol)->whereType(3)->get());
            $trades_5 = $trades_5->mergeRecursive($user->bettings()->whereSymbol($symbol)->whereType(5)->get());
        } else {
            $trades_1 = $trades_1->mergeRecursive($user->bettings()->whereSymbol($symbol)->whereDate('created_at', $date)->whereType(1)->get());
            $trades_3 = $trades_3->mergeRecursive($user->bettings()->whereSymbol($symbol)->whereDate('created_at', $date)->whereType(3)->get());
            $trades_5 = $trades_5->mergeRecursive($user->bettings()->whereSymbol($symbol)->whereDate('created_at', $date)->whereType(5)->get());
        }

        if (!$user->isUser()) {
            foreach ($allBranchUsers as $branch) {
                if (!$branch->user) {
                    continue;
                }

                if ($request->has('all')) {
                    $trades_1 = $trades_1->mergeRecursive($branch->user->bettings()->whereSymbol($symbol)->whereType(1)->get());
                    $trades_3 = $trades_3->mergeRecursive($branch->user->bettings()->whereSymbol($symbol)->whereType(3)->get());
                    $trades_5 = $trades_5->mergeRecursive($branch->user->bettings()->whereSymbol($symbol)->whereType(5)->get());
                } else {
                    $trades_1 = $trades_1->mergeRecursive($branch->user->bettings()->whereSymbol($symbol)->whereDate('created_at', $date)->whereType(1)->get());
                    $trades_3 = $trades_3->mergeRecursive($branch->user->bettings()->whereSymbol($symbol)->whereDate('created_at', $date)->whereType(3)->get());
                    $trades_5 = $trades_5->mergeRecursive($branch->user->bettings()->whereSymbol($symbol)->whereDate('created_at', $date)->whereType(5)->get());
                }
            }
        }

        $trades_1 = $trades_1->sortBy('round')->groupBy('round')->reverse();
        $trades_3 = $trades_3->sortBy('round')->groupBy('round')->reverse();
        $trades_5 = $trades_5->sortBy('round')->groupBy('round')->reverse();

        if ($request->has('all')) {
            $daily_rolling_1['correct'] = $user->bettings()->whereSymbol($symbol)->whereType(1)->whereResult('correct')->sum('amount');
            $daily_rolling_3['correct'] = $user->bettings()->whereSymbol($symbol)->whereType(3)->whereResult('correct')->sum('amount');
            $daily_rolling_5['correct'] = $user->bettings()->whereSymbol($symbol)->whereType(5)->whereResult('correct')->sum('amount');
            $daily_rolling_1['incorrect'] = $user->bettings()->whereSymbol($symbol)->whereType(1)->whereResult('incorrect')->sum('amount');
            $daily_rolling_3['incorrect'] = $user->bettings()->whereSymbol($symbol)->whereType(3)->whereResult('incorrect')->sum('amount');
            $daily_rolling_5['incorrect'] = $user->bettings()->whereSymbol($symbol)->whereType(5)->whereResult('incorrect')->sum('amount');
        } else {
            $daily_rolling_1['correct'] = $user->bettings()->whereSymbol($symbol)->whereType(1)->whereDate('created_at', $date)->whereResult('correct')->sum('amount');
            $daily_rolling_3['correct'] = $user->bettings()->whereSymbol($symbol)->whereType(3)->whereDate('created_at', $date)->whereResult('correct')->sum('amount');
            $daily_rolling_5['correct'] = $user->bettings()->whereSymbol($symbol)->whereType(5)->whereDate('created_at', $date)->whereResult('correct')->sum('amount');
            $daily_rolling_1['incorrect'] = $user->bettings()->whereSymbol($symbol)->whereType(1)->whereDate('created_at', $date)->whereResult('incorrect')->sum('amount');
            $daily_rolling_3['incorrect'] = $user->bettings()->whereSymbol($symbol)->whereType(3)->whereDate('created_at', $date)->whereResult('incorrect')->sum('amount');
            $daily_rolling_5['incorrect'] = $user->bettings()->whereSymbol($symbol)->whereType(5)->whereDate('created_at', $date)->whereResult('incorrect')->sum('amount');
        }

        foreach ($allBranchUsers as $branch) {
            $branch_user = $branch->user;
            if (!$branch_user) {
                continue;
            }

            if ($request->has('all')) {
                $daily_rolling_1['correct'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(1)->whereResult('correct')->sum('amount');
                $daily_rolling_3['correct'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(3)->whereResult('correct')->sum('amount');
                $daily_rolling_5['correct'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(5)->whereResult('correct')->sum('amount');
                $daily_rolling_1['incorrect'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(1)->whereResult('incorrect')->sum('amount');
                $daily_rolling_3['incorrect'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(3)->whereResult('incorrect')->sum('amount');
                $daily_rolling_5['incorrect'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(5)->whereResult('incorrect')->sum('amount');
            } else {
                $daily_rolling_1['correct'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(1)->whereDate('created_at', $date)->whereResult('correct')->sum('amount');
                $daily_rolling_3['correct'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(3)->whereDate('created_at', $date)->whereResult('correct')->sum('amount');
                $daily_rolling_5['correct'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(5)->whereDate('created_at', $date)->whereResult('correct')->sum('amount');
                $daily_rolling_1['incorrect'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(1)->whereDate('created_at', $date)->whereResult('incorrect')->sum('amount');
                $daily_rolling_3['incorrect'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(3)->whereDate('created_at', $date)->whereResult('incorrect')->sum('amount');
                $daily_rolling_5['incorrect'] += $branch_user->bettings()->whereSymbol($symbol)->whereType(5)->whereDate('created_at', $date)->whereResult('incorrect')->sum('amount');
            }
        }

        return view('branch.trades', [
            'symbol' => $symbol,
            'date' => $date,
            'trades_1' => $trades_1,
            'trades_3' => $trades_3,
            'trades_5' => $trades_5,
            'daily_rolling_1' => $daily_rolling_1,
            'daily_rolling_3' => $daily_rolling_3,
            'daily_rolling_5' => $daily_rolling_5,
        ]);
    }

    public function listTransaction(Request $request, User $user = NULL)
    {
        $is_arg_user_null = $user == NULL;

        $user = $user ? $user : $request->user();

        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        if ($is_arg_user_null) {
            $dt_link = route('branch.tx.list.datatable');
        } else {
            $dt_link = route('branch.user.tx.list.datatable', $user);
        }

        return view('branch.transactions', [
            'type' => 'normal',
            'dt_link' => $dt_link,
        ]);
    }

    public function listTransactionDT(Request $request, User $user = NULL)
    {
        $is_arg_user_null = $user == NULL;

        $user = $user ? $user : $request->user();

        if (!$user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        if ($request->type == 'fee') {
            $transactions = FeeTransaction::whereIn('type', ['withdraw', 'withdraw_give']);
        } else {
            if ($request->user()->isMaster() && $is_arg_user_null) {
                $transactions = Transaction::whereIn('type', ['deposit', 'withdraw', 'deposit_manual', 'withdraw_manual']);
            } else {
                $allBranchUsers = $user->allSubBranchUsers();

                $users = [$user->id];

                foreach ($allBranchUsers as $branch) {
                    if (!$branch->user) {
                        continue;
                    }

                    $users[] = $branch->user->id;
                }

                if ($is_arg_user_null) {
                    $transactions = Transaction::whereIn('type', ['deposit', 'withdraw', 'deposit_manual', 'withdraw_manual'])->whereIn('user_id', $users)->whereStatus('success');
                } else {
                    $transactions = Transaction::whereIn('type', ['deposit', 'withdraw', 'deposit_manual', 'withdraw_manual'])->whereIn('user_id', $users)->whereStatus('success');
                }
            }
        }

        $datatables = DataTables::of($transactions)
            ->addColumn('name_link', function($tx) {
                if (!$tx->user) {
                    return '탈퇴한 회원';
                }

                return "<a href=\"".route('branch.user.show', $tx->user->id)."\">{$tx->user->name} ({$tx->user->account})</a>";
            })
            ->addColumn('branch', function($tx) {
                if (!$tx->user || !$tx->user->parentBranch) {
                    return '없음';
                }

                $branch_user = $tx->user->parentBranch->branchUser;
                return $branch_user->name." ({$branch_user->account})";
            })
            ->addColumn('type_string', function($tx) {
                if ($tx->isDeposit()) {
                    return '<span class="text-primary"><i class="fas fa-plus"></i> 입금</span>';
                } else if ($tx->isWithdraw()) {
                    return '<span class="text-danger"><i class="fas fa-minus"></i> 출금</span>';
                } else if ($tx->type == 'deposit_manual') {
                    return '<span class="text-primary"><i class="fas fa-plus"></i> 수동입금</span>';
                } else if ($tx->type == 'withdraw_manual') {
                    return '<span class="text-danger"><i class="fas fa-minus"></i> 수동출금</span>';
                } else if ($tx->type == 'withdraw_give') {
                    return '<span class="text-danger"><i class="fas fa-minus"></i> 수동출금</span>';
                }
            })
            ->addColumn('amount_formatted', function($tx) {
                return number_format($tx->amount);
            })
            ->addColumn('info_formatted', function($tx) use ($request) {
                if ($request->user()->isMaster()) {
                    return $tx->info;
                } else {
                    return '';
                }
            })
            ->addColumn('status_string', function($tx) {
                if ($tx->isSuccess()) {
                    return '<i class="fas fa-check text-success"></i> <span>완료</span>';
                } else if ($tx->isFailed()) {
                    return '<i class="fas fa-times text-danger"></i> <span>실패</span>';
                } else if ($tx->status == 'waiting') {
                    return '<i class="fas fa-minus text-warning"></i> <span>처리대기</span>';
                } else {
                    return '<i class="fas fa-minus text-secondary"></i> <span>대기</span>';
                }
            })
            ->addColumn('btn_approve', function($tx) use ($request) {
                if ($request->user()->isMaster() && ($tx->status == 'pending' || $tx->status == 'waiting')) {
                    if ($request->type == 'fee') {
                        return "<a href=\"".route('branch.fee_tx.update', $tx->id)."\" class=\"btn btn-success btn-sm tx-approve\">승인</a>";
                    } else {
                        return "<a href=\"".route('branch.tx.update', $tx->id)."\" class=\"btn btn-success btn-sm tx-approve\">승인</a>";
                    }
                } else {
                    return '';
                }
            })
            ->addColumn('btn_disapprove', function($tx) use ($request) {
                if ($request->user()->isMaster() && ($tx->status == 'pending' || $tx->status == 'waiting')) {
                    if ($request->type == 'fee') {
                        return "<a href=\"".route('branch.fee_tx.update', $tx->id)."\" class=\"btn btn-danger btn-sm tx-disapprove\">취소</a>";
                    } else {
                        return "<a href=\"".route('branch.tx.update', $tx->id)."\" class=\"btn btn-danger btn-sm tx-disapprove\">취소</a>";
                    }
                } else {
                    return '';
                }
            })
            ->addColumn('btn_waiting', function($tx) use ($request) {
                if ($request->user()->isMaster() && ($tx->status == 'pending' || $tx->status == 'waiting')) {
                    if ($request->type == 'fee') {
                        return "<a href=\"".route('branch.fee_tx.update', $tx->id)."\" class=\"btn btn-warning btn-sm tx-waiting\">대기</a>";
                    } else {
                        return "<a href=\"".route('branch.tx.update', $tx->id)."\" class=\"btn btn-warning btn-sm tx-waiting\">대기</a>";
                    }
                } else {
                    return '';
                }
            })
            ->addColumn('created_at_formatted', function($tx) {
                return $tx->created_at->format('Y-m-d H:i:s');
            })
            ->rawColumns(['name_link', 'type_string', 'status_string', 'btn_approve', 'btn_disapprove', 'btn_waiting'])
            ->orderColumn('created_at', '-created_at $1');

        return $datatables->toJson();
    }

    public function updateTransaction(Request $request, Transaction $transaction)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        if ($transaction->status != 'pending' && $transaction->status != 'waiting') {
            return response([
                'message' => '이미 처리된 요청입니다',
            ], 403);
        }

        $transaction->status = $request->status;
        $transaction->save();

        if ($transaction->status == 'success') {
            if ($transaction->type == 'deposit') {
                $transaction->user->increment('balance', $transaction->amount);
            }
        } else if ($transaction->status == 'failed') {
            if ($transaction->type == 'withdraw') {
                $transaction->user->increment('balance', $transaction->amount);
            }
        }

        return response()->noContent();
    }

    public function listFeeTransaction(Request $request)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        $is_arg_user_null = NULL;

        $dt_link = route('branch.tx.list.datatable');
        $type = 'fee';

        return view('branch.transactions', [
            'type' => 'fee',
            'dt_link' => $dt_link,
        ]);
    }

    public function updateFeeTransaction(Request $request, FeeTransaction $fee_transaction)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        $fee_transaction->status = $request->status;
        $fee_transaction->save();

        if ($fee_transaction->status == 'success') {
            if ($fee_transaction->type == 'deposit') {
                $fee_transaction->user->increment('fee_balance', $fee_transaction->amount);
            }
        } else if ($fee_transaction->status == 'failed') {
            if ($fee_transaction->type == 'withdraw') {
                $fee_transaction->user->increment('fee_balance', $fee_transaction->amount);
            }
        }

        return response()->noContent();
    }

    public function listWaitingTrades(Request $request)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        $symbol = $this->symbolProcess($request->symbol);

        return view('branch.waiting_trades', [
            'symbol' => $symbol,
        ]);
    }

    public function listWaitingTradesJson(Request $request)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        $symbol = $this->symbolProcess($request->symbol);

        $play_round_1 = str_pad(ceil(Carbon::now()->diffInSeconds((new Carbon('-60 seconds'))->startOfDay()) / 60) % 1440, 4, '0', STR_PAD_LEFT);

        if ($play_round_1 == 0) {
            $play_round_1 = date('ymd', time() - 60).'1440';
        } else {
            $play_round_1 = date('ymd', time() - 60).$play_round_1;
        }

        $play_round_3 = str_pad(ceil(Carbon::now()->diffInSeconds((new Carbon('-180 seconds'))->startOfDay()) / 180) % 480, 4, '0', STR_PAD_LEFT);

        if ($play_round_3 == 0) {
            $play_round_3 = date('ymd', time() - 180).'0480';
        } else {
            $play_round_3 = date('ymd', time() - 180).$play_round_3;
        }

        $play_round_5 = str_pad(ceil(Carbon::now()->diffInSeconds((new Carbon('-300 seconds'))->startOfDay()) / 300) % 288, 4, '0', STR_PAD_LEFT);

        if ($play_round_5 == 0) {
            $play_round_5 = date('ymd', time() - 300).'0288';
        } else {
            $play_round_5 = date('ymd', time() - 300).$play_round_5;
        }

        $up_users_1 = [];
        $down_users_1 = [];
        $up_users_3 = [];
        $down_users_3 = [];
        $up_users_5 = [];
        $down_users_5 = [];

        $bettings_1 = Betting::whereSymbol($symbol)->whereType(1)->whereRound($play_round_1)->cursor();
        $bettings_3 = Betting::whereSymbol($symbol)->whereType(3)->whereRound($play_round_3)->cursor();
        $bettings_5 = Betting::whereSymbol($symbol)->whereType(5)->whereRound($play_round_5)->cursor();

        foreach ($bettings_1 as $betting) {
            if ($betting->pick == 'up') {
                $up_users_1[$betting->user->name] = bcmul($betting->amount, 10000);
            } else {
                $down_users_1[$betting->user->name] = bcmul($betting->amount, 10000);
            }
        }

        foreach ($bettings_3 as $betting) {
            if ($betting->pick == 'up') {
                $up_users_3[$betting->user->name] = bcmul($betting->amount, 10000);
            } else {
                $down_users_3[$betting->user->name] = bcmul($betting->amount, 10000);
            }
        }

        foreach ($bettings_5 as $betting) {
            if ($betting->pick == 'up') {
                $up_users_5[$betting->user->name] = bcmul($betting->amount, 10000);
            } else {
                $down_users_5[$betting->user->name] = bcmul($betting->amount, 10000);
            }
        }

        return response([
            '1m' => [
                'round' => $play_round_1,
                'up' => $up_users_1,
                'down' => $down_users_1,
            ],
            '3m' => [
                'round' => $play_round_3,
                'up' => $up_users_3,
                'down' => $down_users_3,
            ],
            '5m' => [
                'round' => $play_round_5,
                'up' => $up_users_5,
                'down' => $down_users_5,
            ],
        ]);
    }

    public function listUnplayedTrades(Request $request)
    {
        $symbol = $this->symbolProcess($request->symbol);

        $unplayed_trades = Betting::whereSymbol($symbol)->whereNull('result')->where('created_at', '<', now()->subMinutes(3))->get();
        $manual_inserts = GameResult::whereSymbol($symbol)->whereManualInsert(true)->orderByDesc('round')->get();

        return view('branch.unplayed_trades', [
            'symbol' => $symbol,
            'unplayed_trades' => $unplayed_trades,
            'manual_inserts' => $manual_inserts,
        ]);
    }

    public function createGameResult(Request $request)
    {
        $symbol = $this->symbolProcess($request->symbol, true);

        Artisan::call("game:manualrun {$symbol} {$request->type} {$request->round} {$request->open} {$request->close}");
        return response()->noContent();
    }

    public function getConfig(Request $request)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        $config = [
            'bet_close_btcusdt' => file_exists(storage_path('framework/bet_close_btcusdt')),
            'bet_close_gbpaud' => file_exists(storage_path('framework/bet_close_gbpaud')),
            'ban_ips' => BanIp::all(),
            'admin_ips' => AdminIp::all(),
        ];

        $db_configs = DB::table('config')->get();

        foreach ($db_configs as $db_config) {
            $config[$db_config->key] = $db_config->value;
        }

        return view('branch.config', [
            'config' => $config,
        ]);
    }

    public function setConfig(Request $request)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        if ($request->has('bet_close_btcusdt')) {
            if ($request->bet_close_btcusdt == 'true') {
                file_put_contents(storage_path('framework/bet_close_btcusdt'), date('Y-m-d H:i:s'));
            } else {
                unlink(storage_path('framework/bet_close_btcusdt'));
            }
        }

        if ($request->has('bet_close_gbpaud')) {
            if ($request->bet_close_gbpaud == 'true') {
                file_put_contents(storage_path('framework/bet_close_gbpaud'), date('Y-m-d H:i:s'));
            } else {
                unlink(storage_path('framework/bet_close_gbpaud'));
            }
        }

        if ($request->has('deposit_bank')) {
            DB::table('config')->updateOrInsert(
                ['key' => 'deposit_bank'],
                ['value' => e($request->deposit_bank ?? '')]
            );
        }

        if ($request->has('deposit_info')) {
            DB::table('config')->updateOrInsert(
                ['key' => 'deposit_info'],
                ['value' => e($request->deposit_info ?? '')]
            );
        }

        if ($request->has('withdraw_info')) {
            DB::table('config')->updateOrInsert(
                ['key' => 'withdraw_info'],
                ['value' => e($request->withdraw_info ?? '')]
            );
        }

        if ($request->has('contact_info')) {
            DB::table('config')->updateOrInsert(
                ['key' => 'contact_info'],
                ['value' => e($request->contact_info ?? '')]
            );
        }

        if ($request->has('ban_ip_addr')) {
            if ($request->action == 'add') {
                $banIp = new BanIp;
                $banIp->ip_addr = $request->ban_ip_addr;
                $banIp->save();
            } else if ($request->action == 'remove') {
                $banIp = BanIp::whereIpAddr($request->ban_ip_addr)->first();
                $banIp->delete();
            }
        }

        if ($request->has('admin_ip_addr')) {
            if ($request->action == 'add') {
                $adminIp = new AdminIp;
                $adminIp->ip_addr = $request->admin_ip_addr;
                $adminIp->save();
            } else if ($request->action == 'remove') {
                $adminIp = AdminIp::whereIpAddr($request->admin_ip_addr)->first();
                $adminIp->delete();
            }
        }

        return response()->noContent();
    }

    public function getNewRequest(Request $request)
    {
        $req = '';

        $tx = Transaction::where('created_at', '>=', date('Y-m-d H:i:s', strtotime('-1 hour')))->whereIn('type', ['deposit', 'withdraw'])->whereStatus('pending');
        if ($tx->exists()) {
            $req = $tx->first()->type;
        }

        $fee_tx = FeeTransaction::where('created_at', '>=', date('Y-m-d H:i:s', strtotime('-1 hour')))->whereType('withdraw')->whereStatus('pending');
        if ($fee_tx->exists()) {
            $req = $fee_tx->first()->type;
        }

        $contact = Contact::where('created_at', '>=', date('Y-m-d H:i:s', strtotime('-1 hour')))->whereNull('reply');
        if ($contact->exists()) {
            $req = 'contact';
        }

        return response([
            'new' => $req != '',
            'req' => $req,
        ]);
    }
}
