<?php

namespace App\Http\Controllers;

use DB;
use App\TickData;
use Carbon\Carbon;
use Illuminate\Http\Request;

class ChartController extends Controller
{
    public function getConfig(Request $request)
    {
        return response([
            'supported_resolutions' => ['1', '3', '5', '15', '30', '60', '1D', '1W', '1M'],
            'supports_group_request' => false,
            'supports_marks' => false,
            'supports_search' => true,
            'supports_timescale_marks' => false,
            'supports_time' => true,
        ]);
    }

    public function getTime(Request $request)
    {
        return response(time());
    }

    public function getSymbolInfo(Request $request)
    {
        return response([
            'symbol' => ['GBPAUD'],
            'description' => ['British Pound / Australian Dollar'],
            'exchange-listed' => 'Live-Rates',
            'exchange-traded' => 'Live-Rates',
            'minmovement' => 1,
            'minmovement2' => 0,
            'pricescale' => [100000],
            'has-dwm' => true,
            'has-intraday' => true,
            'has-no-volume' => [true],
            'type' => ['forex'],
            'ticker' => ['GBP/AUD'],
            'timezone' => 'Asia/Seoul',
            'session-regular' => '24x7',
        ]);
    }

    public function getSymbols(Request $request)
    {
        return response([
            'name' => 'GBPAUD',
            'ticker' => 'GBPAUD',
            'description' => 'British Pound / Australian Dollar',
            'type' => 'forex',
            'session' => '24x7',
            // 'holidays' => '',
            // 'corrections' => '',
            'exchange' => 'Live-Rates',
            'listed_exchange' => 'Live-Rates',
            'timezone' => 'Asia/Seoul',
            'format' => 'price',
            'minmovement' => 1,
            // 'minmovement2' => 0,
            'pricescale' => 100000,
            'fractional' => false,
            'has_intraday' => true,
            'supported_resolutions' => ['1', '3', '5', '15', '30', '60', '1D', '1W'],
            'intraday_multipliers' => ['1', '3', '5', '15', '30', '60', '1D', '1W'],
            'has_seconds' => false,
            // 'seconds_multipliers' => [],
            'has_daily' => true,
            'has_weekly_and_monthly' => true,
            'has_empty_bars' => true,
            'force_session_rebuild' => true,
            'has_no_volume' => true,
            // 'volume_precision' => 0,
            'data_status' => 'streaming',
            'expired' => false,
            // 'sector' => 'testsector',
            // 'industry' => 'forex',
            // 'original_currency_code' => 'GBPAUD',
            // 'currency_code' => 'GBPAUD',
        ]);
    }

    public function getHistory(Request $request)
    {
        $exists_tickdata = TickData::where('created_at', '>=', (new Carbon((int) $request->from))->tz('Asia/Seoul')->format('Y-m-d H:i:s'))->where('created_at', '<=', (new Carbon((int) $request->to))->tz('Asia/Seoul')->format('Y-m-d H:i:s'))->exists();

        if (!$exists_tickdata) {
            $next_available_tick = TickData::where('created_at', '<', (new Carbon((int) $request->from))->tz('Asia/Seoul')->format('Y-m-d H:i:s'))->orderBy('created_at', 'desc')->first();

            return response([
                's' => 'no_data',
                'nextTime' => $next_available_tick ? $next_available_tick->created_at->timestamp : NULL,
            ]);
        }

        if (mb_substr($request->resolution, -1, 1) == 'D') {
            $minutes = mb_substr($request->resolution, 0, -1) * 3600;
        } else if (mb_substr($request->resolution, -1, 1) == 'W') {
            $minutes = mb_substr($request->resolution, 0, -1) * 3600 * 7;
        } else {
            $minutes = (int) $request->resolution;
        }

        $data = [
            'timestamp' => [],
            'open' => [],
            'high' => [],
            'low' => [],
            'close' => [],
            'volume' => []
        ];

        $tick_data =
            DB::query()->select(
                't.time',
                DB::raw('(SELECT t2.price FROM tick_data AS t2 WHERE t2.id = t.o_id) AS o'),
                't.h',
                't.l',
                DB::raw('(SELECT t2.price FROM tick_data AS t2 WHERE t2.id = t.c_id) AS c')
            )
            ->fromSub(function ($query) use ($request, $minutes) {
                $query->select(
                    DB::raw('FROM_UNIXTIME('.$minutes.' * 60 * (UNIX_TIMESTAMP(created_at) DIV ('.$minutes.' * 60))) AS time'),
                    DB::raw('MIN(id) AS o_id'),
                    DB::raw('MAX(price) AS h'),
                    DB::raw('MIN(price) AS l'),
                    DB::raw('MAX(id) AS c_id')
                );
                $query->from('tick_data');
                $query->where('created_at', '>=', (new Carbon((int) $request->from))->tz('Asia/Seoul')->format('Y-m-d H:i:s'));
                $query->where('created_at', '<=', (new Carbon((int) $request->to))->tz('Asia/Seoul')->format('Y-m-d H:i:s'));
                $query->groupBy('time');
            }, 't')
            ->groupBy('t.time')
            ->cursor();

        foreach ($tick_data as $tick) {
            $data['timestamp'][] = (new Carbon($tick->time))->tz('Asia/Seoul')->timestamp;
            $data['open'][] = $tick->o;
            $data['high'][] = $tick->h;
            $data['low'][] = $tick->l;
            $data['close'][] = $tick->c;
            $data['volume'][] = 0;
        }

        return response([
            's' => 'ok',
            't' => $data['timestamp'],
            'o' => $data['open'],
            'h' => $data['high'],
            'l' => $data['low'],
            'c' => $data['close'],
            'v' => $data['volume'],
        ]);
    }
}
