<?php

namespace App\Http\Controllers;

use DataTables;
use App\Contact;
use Illuminate\Http\Request;

class ContactController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function list(Request $request)
    {
        $contacts = Contact::whereUserId($request->user()->id)->orderBy('id', 'desc')->take(15)->get();

        return view('contacts', [
            'contacts' => $contacts,
        ]);
    }

    public function listAdmin(Request $request)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('main');
        }

        return view('branch.contacts');
    }

    public function listAdminDT(Request $request)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('main');
        }

        $contacts = Contact::orderBy('id', 'desc');

        $datatables = DataTables::of($contacts)
            ->addColumn('subject_link', function($contact) {
                return "<div class=\"text-left\"><a href=\"".route('branch.contact.show', $contact->id)."\">{$contact->subject}</a></div>";
            })
            ->addColumn('name_link', function($contact) {
                if ($contact->user) {
                    return "<a href=\"".route('branch.user.show', $contact->user->id)."\">{$contact->user->name} ({$contact->user->account})</a>";
                } else {
                    return '탈퇴한 회원';
                }
            })
            ->addColumn('is_replied_string', function($contact) {
                return $contact->isReplied() ? '<span class="text-success">답변됨</span>' : '<span class="text-danger">답변안됨</span>';
            })
            ->addColumn('created_at_formatted', function($user) {
                return $user->created_at->format('Y-m-d H:i:s');
            })
            ->addColumn('delete_link', function($contact) {
                return "<a href=\"".route('branch.contact.delete', $contact->id)."\" class=\"btn btn-danger btn-sm delete-contact\">삭제</a>";
            })
            ->rawColumns(['subject_link', 'name_link', 'is_replied_string', 'delete_link']);

        return $datatables->toJson();
    }

    public function create(Request $request)
    {
        $contact = new Contact;

        $contact->user_id = $request->user()->id;
        $contact->subject = $request->subject;
        $contact->content = e($request->content);
        $contact->save();

        return redirect()->route('contact.show', $contact);
    }

    public function reply(Request $request, Contact $contact)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('contact.list');
        }

        $contact->reply = e($request->reply);
        $contact->save();

        return redirect()->route('branch.contact.show', $contact);
    }

    public function delete(Request $request, Contact $contact)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('contact.list');
        }

        $contact->delete();

        return response()->noContent();
    }

    public function show(Request $request, Contact $contact)
    {
        if ($contact->user_id != $request->user()->id && !$request->user()->isMaster()) {
            return redirect()->route('contact.list');
        }

        return view('contact', [
            'contact' => $contact,
        ]);
    }

    public function showAdmin(Request $request, Contact $contact)
    {
        if ($contact->user_id != $request->user()->id && !$request->user()->isMaster()) {
            return redirect()->route('contact.list');
        }

        return view('branch.contact', [
            'contact' => $contact,
        ]);
    }
}
