<?php

namespace App\Http\Controllers;

use App\User;
use App\Note;
use Illuminate\Http\Request;

class NoteController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function list(Request $request, $notice = NULL)
    {
        $notes = $request->user()->receivedNotes->reverse();

        return view('notes', [
            'notes' => $notes,
        ]);
    }

    public function show(Request $request, Note $note)
    {
        if ($note->to_user_id != $request->user()->id && !$request->user()->isMaster()) {
            return redirect()->route('note.list');
        }

        if ($note->readed_at == NULL) {
            $note->readed_at = now();
            $note->save();
        }

        return view('note', [
            'note' => $note,
        ]);
    }

    public function showForm(Request $request)
    {
        $to_user = User::find($request->user_id);

        return view('branch.note_form', [
            'to_user' => $to_user,
        ]);
    }

    public function sendNote(Request $request)
    {
        $to_user = User::find($request->user_id);

        if ($to_user->user_type != 'master' && !$to_user->isMyBranch($request->user()->id)) {
            $request->session()->flash('message', '권한이 없습니다');

            return redirect()->route('branch.main');
        }

        $note = new Note;

        $note->user_id = $request->user()->id;
        $note->to_user_id = $to_user->id;
        $note->content = e($request->content);

        $note->save();

        $request->session()->flash('message', '쪽지가 전송되었습니다');

        return redirect()->route('branch.note.form', [
            'user_id' => $request->user_id,
        ]);
    }
}
