<?php

namespace App\Http\Controllers;

use App\Notice;
use Illuminate\Http\Request;

class NoticeController extends Controller
{
    public function __construct()
    {
        //
    }

    public function list(Request $request, $notice = NULL)
    {
        $notices = Notice::whereTarget('user')->orderBy('id', 'desc')->take(15)->get();

        return view('notices', [
            'notices' => $notices,
            'selected_notice' => $notice,
        ]);
    }

    public function listBranch(Request $request)
    {
        $notices = Notice::whereTarget('branch')->orderBy('id', 'desc')->take(15)->get();

        return view('branch.notices', [
            'notices' => $notices,
            'selected_notice' => NULL,
        ]);
    }

    public function showForm(Request $request, Notice $notice)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        return view('branch.notice_form', [
            'notice' => $notice,
        ]);
    }

    public function create(Request $request)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        $notice = new Notice;

        $notice->subject = $request->subject;
        $notice->content = e($request->content);
        $notice->created_at = $request->created_at.date(' H:i:s') ?: date('Y-m-d H:i:s');
        $notice->target = $request->to_branch == 'on' ? 'branch' : 'user';
        $notice->save();

        if ($request->to_branch == 'on') {
            return redirect()->route('branch.notice.list');
        } else {
            return redirect()->route('notice.list', $notice);
        }
    }

    public function update(Request $request, Notice $notice)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('branch.main');
        }

        $notice->subject = $request->subject;
        $notice->content = e($request->content);
        $notice->created_at = $request->created_at.$notice->created_at->format(' H:i:s') ?: date('Y-m-d H:i:s');
        $notice->save();

        return redirect()->route('notice.list', $notice);
    }

    public function delete(Request $request, Notice $notice)
    {
        if (!$request->user()->isMaster()) {
            return redirect()->route('main');
        }

        $notice->delete();

        return response()->noContent();
    }
}
