<?php

namespace App\Http\Controllers;

use Auth;
use App\Transaction;
use Illuminate\Http\Request;

class TxController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $transactions = Auth::user()->transactions()->whereIn('type', ['deposit', 'withdraw'])->latest()->get();

        return view('transactions', [
            'transactions' => $transactions,
        ]);
    }

    public function updateBankInfo(Request $request)
    {
        $user = $request->user();

        if ($user->bank_info) {
            $request->session()->flash('message', '이미 계좌 정보가 등록되어 있습니다. 변경을 원하시면 관리자에게 문의해주세요.');

            return redirect()->back();
        }

        $user->bank_info = "{$request->bank_name} / {$request->bank_address} / {$request->bank_owner} / {$request->contact}";
        $user->save();

        $request->session()->flash('message', '계좌 정보가 등록되었습니다');

        return redirect()->back();
    }

    public function deposit(Request $request)
    {
        $user = $request->user();
        $amount = str_replace(',', '', $request->amount);

        if ($user->hasPendingTransaction('deposit')) {
            $request->session()->flash('message', '이미 대기중인 입금 신청이 있습니다');

            return redirect()->route('tx.index');
        }

        if ($amount <= 0) {
            $request->session()->flash('message', '수량이 올바르지 않습니다');
            return redirect()->route('tx.index');
        }

        $tx = new Transaction;

        $tx->user_id = $user->id;
        $tx->type = 'deposit';
        $tx->amount = $amount;
        $tx->info = $user->bank_info;

        $tx->save();

        $request->session()->flash('message', '입금 신청이 완료되었습니다');

        return redirect()->route('tx.index');
    }

    public function withdraw(Request $request)
    {
        $user = $request->user();
        $amount = str_replace(',', '', $request->amount);

        if ($user->hasPendingTransaction('withdraw')) {
            $request->session()->flash('message', '이미 대기중인 출금 신청이 있습니다');

            return redirect()->route('tx.index');
        }

        if ($amount <= 0) {
            $request->session()->flash('message', '수량이 올바르지 않습니다');
            return redirect()->route('tx.index');
        }

        if ($user->balance < $amount) {
            $request->session()->flash('message', '보유 금액이 부족합니다');

            return redirect()->route('tx.index');
        }

        if ($amount % 10000 != 0) {
            $request->session()->flash('message', '출금 금액은 10,000원 단위로 가능합니다');

            return redirect()->route('tx.index');
        }

        $tx = new Transaction;

        $tx->user_id = $user->id;
        $tx->type = 'withdraw';
        $tx->amount = $amount;
        $tx->info = $user->bank_info;

        $tx->save();

        $user->decrement('balance', $tx->amount);

        $request->session()->flash('message', '출금 신청이 완료되었습니다');

        return redirect()->route('tx.index');
    }
}
