<?php

namespace App;

use Auth;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Notifications\Notifiable;
use Yadahan\AuthenticationLog\AuthenticationLogable;

class User extends Authenticatable
{
    use Notifiable, AuthenticationLogable, SoftDeletes;
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'account', 'password', 'name', 'bank_info', 'email'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        //
    ];

    public function fees()
    {
        return $this->hasMany('App\Fee');
    }

    public function transactions()
    {
        return $this->hasMany('App\Transaction');
    }

    public function feeTransactions()
    {
        return $this->hasMany('App\FeeTransaction');
    }

    public function bettings()
    {
        return $this->hasMany('App\Betting');
    }

    public function notes()
    {
        return $this->hasMany('App\Note');
    }

    public function receivedNotes()
    {
        return $this->hasMany('App\Note', 'to_user_id');
    }

    public function totalDeposit()
    {
        $txs = $this->transactions()->whereType('deposit')->whereStatus('success');
        if (!$txs->exists()) {
            return 0;
        }

        return $txs->sum('amount');
    }

    public function totalWithdraw()
    {
        $txs = $this->transactions()->whereType('withdraw')->whereStatus('success');
        if (!$txs->exists()) {
            return 0;
        }

        return $txs->sum('amount');
    }

    public function isSuspended()
    {
        return $this->status == 'suspended';
    }

    public function isUser()
    {
        return $this->user_type == 'user';
    }

    public function isBranch()
    {
        return $this->user_type == 'branch';
    }

    public function isMaster()
    {
        return $this->user_type == 'master';
    }

    public function hasPendingTransaction($type)
    {
        return $this->transactions()->whereType($type)->whereStatus('pending')->exists();
    }

    public function myFees()
    {
        return $this->hasMany('App\Fee', 'branch_user_id');
    }

    public function parentBranch()
    {
        return $this->hasOne('App\Branch');
    }

    public function myBranch()
    {
        $branches = $this->myBranchUsers;

        $return = collect();

        foreach ($branches as $branch) {
            if ($branch->user && $branch->user->user_type != 'user') {
                $return = $return->merge([$branch]);
            }
        }

        return $return;
    }

    public function myBranchUsers()
    {
        return $this->hasMany('App\Branch', 'branch_user_id')->with('user.parentBranch');
    }

    public function allSubBranchUsers()
    {
        return $this->recursiveAll($this->myBranchUsers);
    }

    public function allSubBranchUserIds()
    {
        return $this->recursiveAllId($this->myBranchUsers);
    }

    public function allParentBranchesId()
    {
        $return = [];
        $user = $this;

        while($user->parentBranch) {
            $return[] = $user->parentBranch->branch_user_id;
            $user = $user->parentBranch->branchUser;
        }

        return $return;
    }

    public function isMyBranch($user_id)
    {
        return (Auth::user() ? Auth::user()->isMaster() : false) || $this->id == $user_id || in_array($user_id, $this->allParentBranchesId());
    }

    public function recursiveAll($branchUsers)
    {
        $append = collect();

        foreach($branchUsers as $branchUser) {
            if (!$branchUser->user) {
                continue;
            }

            $append->push($branchUser);

            if ($branchUser->user->user_type != 'user') {
                $append = $append->merge($this->recursiveAll($branchUser->user->myBranchUsers));
            }
        }

        return $append;
    }

    public function recursiveAllId($branchUsers)
    {
        $append = collect();

        foreach($branchUsers as $branchUser) {
            if (!$branchUser->user) {
                continue;
            }

            $append->push($branchUser->user->id);

            if ($branchUser->user->user_type != 'user') {
                $append = $append->merge($this->recursiveAllId($branchUser->user->myBranchUsers));
            }
        }

        return $append;
    }
}
