@extends('layouts.branch')

@section('page.name', 'contacts')

@push('scripts')
    @if (Auth::user()->isMaster())
        <script>
            $(function() {
                $('.delete-contact').click(function(e) {
                    e.preventDefault();

                    if (!confirm('정말로 삭제하시겠습니까?')) {
                        return
                    }

                    axios.delete($(this).attr('href')).then(function (response) {
                        alert(response.data.message || '문의가 삭제되었습니다');
                        history.back();
                    }).catch(function (error) {
                        if (error.response && error.response.data) {
                            alert(error.response.data.message);
                        } else {
                            alert('삭제에 실패하였습니다');
                        }
                    });
                });
            });
        </script>
    @endif
@endpush

@section('content')
<div class="container py-3">
    <div class="card mb-3">
        <div class="card-header">
            {{ $contact->subject }}
            <a href="{{ route('branch.user.show', $contact->user->id) }}" class="text-secondary ml-2"><small>{{ $contact->user->name }}({{ $contact->user->account }})</small></a>
            <small class="text-secondary">- {{ $contact->created_at->format('Y-m-d H:i:s') }} 작성됨</small>
        </div>
        <div class="card-body">
            {!! nl2br($contact->content) !!}
        </div>
    </div>

    @if ($contact->isReplied())
        <div class="card">
            <div class="card-header">
                문의 답변 내용
            </div>
            <div class="card-body">
                {!! nl2br($contact->reply) !!}
            </div>
        </div>
    @else
        @if (Auth::user()->isMaster())
            <div class="card mb-3">
                <div class="card-body">
                    <h5 class="card-title">답변 작성</h5>
                    <form action="{{ route('branch.contact.reply', $contact->id) }}" method="POST">
                        @csrf

                        <div class="form-group">
                            <label>내용</label>
                            <textarea name="reply" class="form-control" rows="10" required></textarea>
                        </div>

                        <div class="text-right">
                            <button type="submit" class="btn btn-success">작성</button>
                        </div>
                    </form>
                </div>
            </div>
        @endif
    @endif

    @if (Auth::user()->isMaster())
        <div class="text-right">
            <a href="{{ route('branch.contact.list') }}" class="btn btn-link">목록</a>
            <a href="{{ route('branch.contact.delete', $contact) }}" class="btn btn-danger delete-contact">삭제</a>
        </div>
    @endif
</div>
@endsection