@extends('layouts.branch')

@section('page.name', 'contacts')

@push('scripts')
    <script>
        $(function() {
            $('#contacts').DataTable({
                processing: true,
                serverSide: true,
                ajax: "{{ route('branch.contact.list.datatable') }}",
                columns: [
                    {data: 'subject_link', name: 'subject_link'},
                    {data: 'name_link', name: 'name_link'},
                    {data: 'is_replied_string', name: 'is_replied_string'},
                    {data: 'created_at_formatted', name: 'created_at_formatted'},
                    {data: 'delete_link', name: 'delete_link'},
                ],
                order: ['3', 'desc']
            });

            @if (Auth::user()->isMaster())
                $('#contacts').on('click', '.delete-contact', function(e) {
                    e.preventDefault();

                    if (!confirm('정말로 삭제하시겠습니까?')) {
                        return
                    }

                    axios.delete($(this).attr('href')).then(function (response) {
                        alert(response.data.message || '문의가 삭제되었습니다');
                        location.reload();
                    }).catch(function (error) {
                        if (error.response && error.response.data) {
                            alert(error.response.data.message);
                        } else {
                            alert('삭제에 실패하였습니다');
                        }
                    });
                });
        @endif
        });
    </script>
@endpush

@section('content')
<div class="container-fluid py-3">
    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-header">
                    문의 목록
                </div>

                <div class="card-body table-responsive">
                    <table id="contacts" class="table table-hover text-nowrap text-center">
                        <colgroup>
                            <col>
                            <col style="width: 180px">
                            <col style="width: 120px">
                            <col style="width: 200px">
                            <col style="width: 100px">
                        </colgroup>
                        <thead>
                            <tr>
                                <th>제목</th>
                                <th>회원명</th>
                                <th>상태</th>
                                <th>날짜</th>
                                <th>삭제</th>
                            </tr>
                        </thead>

                        <tbody></tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
