@extends('layouts.branch')

@section('page.name', 'main')

@push('scripts')
    <script>
        $(function() {
            if ($('.cleave-phone').length) {
                new Cleave('.cleave-phone', {
                    phone: true,
                    phoneRegionCode: 'KR',
                    delimiter: '-'
                });
            }

            $('.update_user').click(function (e) {
                e.preventDefault();

                if (!confirm('회원 정보를 수정하시겠습니까?')) {
                    return;
                }

                axios.patch($(this).attr('href'), {
                    status: $(this).data('status')
                }).then(function (response) {
                    alert(response.data.message || '회원 정보가 수정되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('수정에 실패하였습니다');
                    }
                });
            });
        });
    </script>
@endpush

@section('content')
<div class="container-fluid py-3">
    <div class="row">
        <div class="col-12 col-md-4">
            <div class="card mb-3">
                <div class="card-body">
                    <h4 class="text-center">{{ $user->name }}</h4>
                    <table class="table table-sm">
                        <colgroup>
                            <col style="width: 120px;">
                        </colgroup>
                        <tbody>
                            <tr>
                                <th class="text-center">지점명</th>
                                <td class="text-right">{{ $user->name }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">소속 지점</th>
                                @if ($user->parentBranch)
                                    <td class="text-right">{{ $user->parentBranch->branchUser->name }} ({{ $user->parentBranch->branchUser->account }})</td>
                                @else
                                    <td class="text-right">없음</td>
                                @endif
                            </tr>
                            <tr>
                                <th class="text-center">개설일</th>
                                <td class="text-right">{{ $user->created_at }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">정산률</th>
                                <td class="text-right">{{ $user->fee_percent }} %</td>
                            </tr>
                            <tr>
                                <th class="text-center">회원 수</th>
                                <td class="text-right">{{ $user->myBranchUsers->count() }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">하부 지점수</th>
                                <td class="text-right">{{ $user->myBranch()->count() }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">계좌정보</th>
                                <td class="text-right">{{ $user->bank_info ? $user->bank_info : '미등록' }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">보유 금액</th>
                                <td class="text-right">{{ number_format($user->balance) }} 원</td>
                            </tr>
                            <tr>
                                <th class="text-center">보유 정산금</th>
                                <td class="text-right">{{ number_format($user->fee_balance) }} 원</td>
                            </tr>
                        </tbody>
                    </table>

                    @if (Auth::user()->id == $user->id)
                        <div class="mt-3">
                            @if ($user->bank_info)
                                <form action="{{ route('branch.withdraw_fee') }}" method="POST">
                                    @csrf

                                    <div class="form-group">
                                        <label>정산 금액</label>
                                        <input type="text" class="form-control" name="amount" placeholder="정산 금액">
                                        <small class="d-block text-right text-secondary">정산 가능 금액: {{ number_format($user->fee_balance) }} 원</small>
                                    </div>

                                    <button type="submit" class="btn btn-outline-primary w-100">정산 요청</button>
                                    <small class="d-block text-secondary">정산 금액은 최소 100,000원 이상이여야 합니다</small>
                                </form>
                            @else
                                <form action="{{ route('branch.tx.bank_info.update') }}" method="POST">
                                    @csrf
                                    @method('PATCH')

                                    <div class="form-group">
                                        <label>은행명</label>
                                        <input type="text" class="form-control" name="bank_name" required>
                                    </div>

                                    <div class="form-group">
                                        <label>계좌번호</label>
                                        <input type="text" class="form-control" name="bank_address" required>
                                    </div>

                                    <div class="form-group">
                                        <label>예금주</label>
                                        <input type="text" class="form-control" name="bank_owner" required>
                                    </div>

                                    <div class="form-group">
                                        <label>전화번호</label>
                                        <input type="text" class="form-control cleave-phone" name="contact" required>
                                    </div>

                                    <button type="submit" class="btn btn-success">계좌 등록</button>
                                </form>
                            @endif
                        </div>
                    @endif
                </div>
            </div>

            @if (Auth::user()->id != $user->id)
                <div class="card mb-3">
                    <div class="card-header">
                        정보 수정
                    </div>

                    <div class="card-body">
                        <form action="{{ route('branch.branch.modify', $user) }}" method="POST">
                            @csrf
                            @method('PATCH')

                            <div class="form-group">
                                <label>비밀번호</label>
                                <input type="password" class="form-control" name="password">
                            </div>

                            <div class="form-group">
                                <label>정산률</label>
                                <input type="text" class="form-control" name="fee_percent" value="{{ $user->fee_percent }}">
                            </div>

                            <div class="text-right">
                                <button type="submit" class="btn btn-success">수정</button>
                            </div>
                        </form>

                        @if (Auth::user()->isMaster())
                            @if ($user->status == 'unregistered')
                                <a href="{{ route('branch.user.update', $user->id) }}" class="btn btn-outline-danger update_user" data-status="normal">탈퇴 해제</a>
                            @else
                                @if ($user->status == 'normal')
                                    <a href="{{ route('branch.user.update', $user->id) }}" class="btn btn-outline-danger update_user" data-status="suspended">일시정지</a>
                                @elseif ($user->status == 'suspended')
                                    <a href="{{ route('branch.user.update', $user->id) }}" class="btn btn-outline-danger update_user" data-status="normal">일시정지 해제</a>
                                @endif
                                <a href="{{ route('branch.user.update', $user->id) }}" class="btn btn-outline-danger update_user" data-status="unregistered">탈퇴</a>
                            @endif
                        @endif
                    </div>
                </div>
            @endif
        </div>

        <div class="col-12 col-md-8">
            <div class="card">
                <div class="card-header">
                    <nav>
                        <div class="nav nav-pills ml-auto" id="nav-tab">
                            @if (Auth::user()->id == 1017)
                                <a class="flex-sm-fill text-sm-center nav-link active" data-toggle="tab" href="#nav-transactions">입출집계</a>
                            @else
                                <a class="flex-sm-fill text-sm-center nav-link active" data-toggle="tab" href="#nav-adjustment">정산결제</a>
                                <a class="flex-sm-fill text-sm-center nav-link" data-toggle="tab" href="#nav-fee_txs">정산 출금내역</a>
                                <a class="flex-sm-fill text-sm-center nav-link" data-toggle="tab" href="#nav-transactions">입출집계</a>
                                @if ($user->user_type == 'master')
                                    <a class="flex-sm-fill text-sm-center nav-link" data-toggle="tab" href="#nav-branch_txs">지점정산</a>
                                @endif
                                <a class="flex-sm-fill text-sm-center nav-link" data-toggle="tab" href="#nav-trade-1m">1분 거래소</a>
                                <a class="flex-sm-fill text-sm-center nav-link" data-toggle="tab" href="#nav-trade-3m">3분 거래소</a>
                                <a class="flex-sm-fill text-sm-center nav-link" data-toggle="tab" href="#nav-trade-5m">5분 거래소</a>
                            @endif
                        </div>
                    </nav>
                </div>
                <div class="card-body">
                    <div class="tab-content" id="nav-tabContent">
                        <div class="tab-pane fade  @if (Auth::user()->id != 1017) show active @endif" id="nav-adjustment">
                            <table class="table">
                                <colgroup>
                                    <col style="width: 160px;">
                                </colgroup>
                                <tbody>
                                    <tr>
                                        <th class="text-center">전월 정산금액</th>
                                        <td class="text-right">{{ number_format($user->myFees()->whereDate('created_at', date('Y-m-d', strtotime('first day of -1 month')))->sum('amount')) }} 원</td>
                                    <tr>
                                    </tr>
                                        <th class="text-center">당월 정산금액</th>
                                        <td class="text-right">{{ number_format($user->myFees()->whereDate('created_at', date('Y-m-d'))->sum('amount')) }} 원</td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">전체 정산금액</th>
                                        <td class="text-right">{{ number_format($user->myFees()->sum('amount')) }} 원</td>
                                    </tr>
                                </tbody>
                            </table>

                            <table class="table text-center">
                                <thead>
                                    <tr>
                                        <th>날짜</th>
                                        <th>금액</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($fees as $date => $date_fee)
                                        <tr>
                                            <td>{{ $date }}</td>
                                            <td class="text-right">{{ number_format($date_fee) }}원</td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>

                        <div class="tab-pane fade" id="nav-fee_txs">
                            <table class="table">
                                <colgroup>
                                    <col style="width: 160px;">
                                </colgroup>
                                <tbody>
                                    <tr>
                                        <th class="text-center">총 정산완료</th>
                                        <td class="text-right">{{ number_format($fee_txs->sum('amount')) }} 원</td>
                                    </tr>
                                </tbody>
                            </table>

                            <table class="table text-center">
                                <thead>
                                    <tr>
                                        <th>날짜</th>
                                        <th>정산완료</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($fee_txs as $fee_tx)
                                        <tr>
                                            <td>{{ $fee_tx->date }}</td>
                                            <td class="text-right">{{ number_format($fee_tx->amount) }}원</td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>

                        <div class="tab-pane fade @if (Auth::user()->id == 1017) show active @endif" id="nav-transactions">
                            <table class="table">
                                <colgroup>
                                    <col style="width: 160px;">
                                </colgroup>
                                <tbody>
                                    <tr>
                                        <th class="text-center">총 입금</th>
                                        <td class="text-right">{{ number_format(array_sum(array_column($transactions_total_monthly, 'deposit'))) }} 원</td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">총 출금</th>
                                        <td class="text-right">{{ number_format(array_sum(array_column($transactions_total_monthly, 'withdraw'))) }} 원</td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">당월 입금</th>
                                        <td class="text-right">{{ number_format($transactions_total_monthly[date('Y-m')]['deposit'] ?? 0) }} 원</td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">당월 출금</th>
                                        <td class="text-right">{{ number_format($transactions_total_monthly[date('Y-m')]['withdraw'] ?? 0) }} 원</td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">전월 입금</th>
                                        <td class="text-right">{{ number_format($transactions_total_monthly[date('Y-m', strtotime('first day of -1 month'))]['deposit'] ?? 0) }} 원</td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">전월 출금</th>
                                        <td class="text-right">{{ number_format($transactions_total_monthly[date('Y-m', strtotime('first day of -1 month'))]['withdraw'] ?? 0) }} 원</td>
                                    </tr>
                                </tbody>
                            </table>

                            <table class="table text-center">
                                <thead>
                                    <tr>
                                        <th>날짜</th>
                                        <th>입금</th>
                                        <th>출금</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($transactions as $date => $date_tx)
                                        <tr>
                                            <td>{{ $date }}</td>
                                            <td class="text-right">{{ number_format($date_tx['deposit']) }}원<small class="d-block text-secondary">{{ count($date_tx['deposit_users']) }}명, {{ $date_tx['deposit_count'] }}건</small></td>
                                            <td class="text-right">{{ number_format($date_tx['withdraw']) }}원<small class="d-block text-secondary">{{ count($date_tx['withdraw_users']) }}명, {{ $date_tx['withdraw_count'] }}건</small></td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>

                        @if ($user->user_type == 'master')
                            <div class="tab-pane fade" id="nav-branch_txs">
                                <table class="table">
                                    <colgroup>
                                        <col style="width: 160px;">
                                    </colgroup>
                                    <tbody>
                                        <tr>
                                            <th class="text-center">총 출금</th>
                                            <td class="text-right">{{ number_format(array_sum(array_column($branch_transactions_total_monthly, 'withdraw'))) }} 원</td>
                                        </tr>
                                        <tr>
                                            <th class="text-center">당월 출금</th>
                                            <td class="text-right">{{ number_format($branch_transactions_total_monthly[date('Y-m')]['withdraw'] ?? 0) }} 원</td>
                                        </tr>
                                        <tr>
                                            <th class="text-center">전월 출금</th>
                                            <td class="text-right">{{ number_format($branch_transactions_total_monthly[date('Y-m', strtotime('first day of -1 month'))]['withdraw'] ?? 0) }} 원</td>
                                        </tr>
                                    </tbody>
                                </table>

                                <table class="table text-center">
                                    <thead>
                                        <tr>
                                            <th>날짜</th>
                                            <th>출금</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        @foreach ($branch_transactions as $date => $date_tx)
                                            <tr>
                                                <td>{{ $date }}</td>
                                                <td class="text-right">{{ number_format($date_tx['withdraw']) }}원<small class="d-block text-secondary">{{ count($date_tx['withdraw_users']) }}명, {{ $date_tx['withdraw_count'] }}건</small></td>
                                            </tr>
                                        @endforeach
                                    </tbody>
                                </table>
                            </div>
                        @endif

                        <div class="tab-pane fade" id="nav-trade-1m">
                            <table class="table">
                                <colgroup>
                                    <col style="width: 160px;">
                                </colgroup>
                                <tbody>
                                    <tr>
                                        <th class="text-center">실현</th>
                                        <td class="text-right">{{ number_format(array_sum(array_column($trades_1, 'correct'))) }} 원<small class="d-block text-secondary">{{ array_sum(array_column($trades_1, 'correct_users')) }}명, {{ array_sum(array_column($trades_1, 'correct_count')) }}건</small></td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">실격</th>
                                        <td class="text-right">{{ number_format(array_sum(array_column($trades_1, 'incorrect'))) }} 원<small class="d-block text-secondary">{{ array_sum(array_column($trades_1, 'incorrect_users')) }}명, {{ array_sum(array_column($trades_1, 'incorrect_count')) }}건</small></td>
                                    </tr>
                                </tbody>
                            </table>

                            <table class="table text-center">
                                <thead>
                                    <tr>
                                        <th>날짜</th>
                                        <th>실현</th>
                                        <th>실격</th>
                                        <th>합계</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($trades_1 as $date => $trade)
                                        <tr>
                                            <td>{{ $date }}</td>
                                            <td class="text-right">{{ number_format($trade['correct']) }}<small class="d-block text-secondary">{{ $trade['correct_count'] }}건, {{ $trade['correct_users'] }}명</small></td>
                                            <td class="text-right">{{ number_format($trade['incorrect']) }}<small class="d-block text-secondary">{{ $trade['incorrect_count'] }}건, {{ $trade['incorrect_users'] }}명</small></td>
                                            <td class="text-right">{{ number_format(bcadd($trade['correct'], $trade['incorrect'])) }}<small class="d-block text-secondary">{{ $trade['correct_count'] + $trade['incorrect_count'] }}건, {{ $trade['correct_users'] + $trade['incorrect_users'] }}명</small></td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>

                        <div class="tab-pane fade" id="nav-trade-3m">
                            <table class="table">
                                <colgroup>
                                    <col style="width: 160px;">
                                </colgroup>
                                <tbody>
                                    <tr>
                                        <th class="text-center">실현</th>
                                        <td class="text-right">{{ number_format(array_sum(array_column($trades_3, 'correct'))) }} 원<small class="d-block text-secondary">{{ array_sum(array_column($trades_3, 'correct_users')) }}명, {{ array_sum(array_column($trades_3, 'correct_count')) }}건</small></td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">실격</th>
                                        <td class="text-right">{{ number_format(array_sum(array_column($trades_3, 'incorrect'))) }} 원<small class="d-block text-secondary">{{ array_sum(array_column($trades_3, 'incorrect_users')) }}명, {{ array_sum(array_column($trades_3, 'incorrect_count')) }}건</small></td>
                                    </tr>
                                </tbody>
                            </table>

                            <table class="table text-center">
                                <thead>
                                    <tr>
                                        <th>날짜</th>
                                        <th>실현</th>
                                        <th>실격</th>
                                        <th>합계</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($trades_3 as $date => $trade)
                                        <tr>
                                            <td>{{ $date }}</td>
                                            <td class="text-right">{{ number_format($trade['correct']) }}<small class="d-block text-secondary">{{ $trade['correct_count'] }}건, {{ $trade['correct_users'] }}명</small></td>
                                            <td class="text-right">{{ number_format($trade['incorrect']) }}<small class="d-block text-secondary">{{ $trade['incorrect_count'] }}건, {{ $trade['incorrect_users'] }}명</small></td>
                                            <td class="text-right">{{ number_format(bcadd($trade['correct'], $trade['incorrect'])) }}<small class="d-block text-secondary">{{ $trade['correct_count'] + $trade['incorrect_count'] }}건, {{ $trade['correct_users'] + $trade['incorrect_users'] }}명</small></td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>

                        <div class="tab-pane fade" id="nav-trade-5m">
                            <table class="table">
                                <colgroup>
                                    <col style="width: 160px;">
                                </colgroup>
                                <tbody>
                                    <tr>
                                        <th class="text-center">실현</th>
                                        <td class="text-right">{{ number_format(array_sum(array_column($trades_5, 'correct'))) }} 원<small class="d-block text-secondary">{{ array_sum(array_column($trades_5, 'correct_users')) }}명, {{ array_sum(array_column($trades_5, 'correct_count')) }}건</small></td>
                                    </tr>
                                    <tr>
                                        <th class="text-center">실격</th>
                                        <td class="text-right">{{ number_format(array_sum(array_column($trades_5, 'incorrect'))) }} 원<small class="d-block text-secondary">{{ array_sum(array_column($trades_5, 'incorrect_users')) }}명, {{ array_sum(array_column($trades_5, 'incorrect_count')) }}건</small></td>
                                    </tr>
                                </tbody>
                            </table>

                            <table class="table text-center">
                                <thead>
                                    <tr>
                                        <th>날짜</th>
                                        <th>실현</th>
                                        <th>실격</th>
                                        <th>합계</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($trades_5 as $date => $trade)
                                        <tr>
                                            <td>{{ $date }}</td>
                                            <td class="text-right">{{ number_format($trade['correct']) }}<small class="d-block text-secondary">{{ $trade['correct_count'] }}건, {{ $trade['correct_users'] }}명</small></td>
                                            <td class="text-right">{{ number_format($trade['incorrect']) }}<small class="d-block text-secondary">{{ $trade['incorrect_count'] }}건, {{ $trade['incorrect_users'] }}명</small></td>
                                            <td class="text-right">{{ number_format(bcadd($trade['correct'], $trade['incorrect'])) }}<small class="d-block text-secondary">{{ $trade['correct_count'] + $trade['incorrect_count'] }}건, {{ $trade['correct_users'] + $trade['incorrect_users'] }}명</small></td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
