@extends('layouts.branch')

@section('page.name', 'notices')

@push('scripts')
    @auth
        @if (Auth::user()->isMaster())
            <script>
                $(function() {
                    $('.delete-notice').click(function(e) {
                        e.preventDefault();

                        if (!confirm('정말로 삭제하시겠습니까?')) {
                            return
                        }

                        axios.delete($(this).attr('href')).then(function (response) {
                            alert(response.data.message || '공지사항이 삭제되었습니다');
                            location.reload();
                        }).catch(function (error) {
                            if (error.response && error.response.data) {
                                alert(error.response.data.message);
                            } else {
                                alert('삭제에 실패하였습니다');
                            }
                        });
                    });
                });
            </script>
        @endif
    @endif
@endpush

@section('content')
<div class="container-fluid py-3">
    <div class="card">
        <div class="card-header">공지사항</div>
        <div class="card-body">
            <div class="accordion" id="notices">
                @forelse($notices as $notice)
                    <div class="card">
                        <div class="card-header">
                            <button class="btn btn-text text-left" type="button" data-toggle="collapse" data-target="#notice_{{ $notice->id }}">
                                <span>{{ $notice->subject }}</span>
                                @if ($notice->created_at->gt(new \Carbon\Carbon(strtotime('-1 day'))))
                                    <span class="badge badge-danger">N</span>
                                @endif
                                <small class="ml-3 text-secondary">{{ $notice->created_at->format('Y-m-d H:i') }}</small>
                            </button>
                        </div>

                        <div id="notice_{{ $notice->id }}" class="collapse{{ ($loop->first ? ' show' : '') }}" data-parent="#notices">
                            <div class="card-body">
                                {!! nl2br($notice->content) !!}
                            </div>

                            @auth
                                @if (Auth::user()->isMaster())
                                    <div class="card-footer text-right">
                                        <a href="{{ route('branch.notice.modify', $notice) }}" class="btn btn-primary">수정</a>
                                        <a href="{{ route('notice.delete', $notice) }}" class="btn btn-danger delete-notice">삭제</a>
                                    </div>
                                @endif
                            @endif
                        </div>
                    </div>
                @empty
                    <div class="card">
                        <div class="card-header">
                            공지사항이 없습니다
                        </div>
                    </div>
                @endforelse
            </div>
        </div>
    </div>
</div>
@endsection
