@extends('layouts.branch')

@section('page.name', 'trades')

@push('scripts')
@endpush

@section('content')
<div class="container-fluid py-3">
    <div class="alert alert-primary">
        당일 총 거래금액: <strong>{{ number_format(bcadd(bcadd(bcmul(array_sum($daily_rolling_1), 10000), bcmul(array_sum($daily_rolling_3), 10000)), bcmul(array_sum($daily_rolling_5), 10000))) }}원</strong>
    </div>

    <div class="mb-3">
        <form class="form-inline">
            <div class="mr-auto">
                <input type="text" class="form-control datepicker mr-sm-2" name="date" value="{{ $date }}">
                <input type="hidden" name="symbol" value="{{ $symbol }}">
                <button class="btn btn-primary mr-sm-2">조회</button>
                <a href="?all" class="btn btn-link">전체보기</a>
            </div>

            <div class="btn-group ml-auto">
                @if (request()->has('all'))
                    <a href="{{ request()->fullUrlWithQuery(['all' => 'all', 'symbol' => 'BTCUSDT']) }}" class="btn {{ $symbol == 'BTCUSDT' ? 'btn-primary' : 'btn-light' }}">BTCUSDT</a>
                    <a href="{{ request()->fullUrlWithQuery(['all' => 'all', 'symbol' => 'GBPAUD']) }}" class="btn {{ $symbol == 'GBPAUD' ? 'btn-primary' : 'btn-light' }}">GBPAUD</a>
                @else
                    <a href="{{ request()->fullUrlWithQuery(['date' => $date, 'symbol' => 'BTCUSDT']) }}" class="btn {{ $symbol == 'BTCUSDT' ? 'btn-primary' : 'btn-light' }}">BTCUSDT</a>
                    <a href="{{ request()->fullUrlWithQuery(['date' => $date, 'symbol' => 'GBPAUD']) }}" class="btn {{ $symbol == 'GBPAUD' ? 'btn-primary' : 'btn-light' }}">GBPAUD</a>
                @endif
            </div>
        </form>
    </div>

    <div class="row">
        <div class="col-12 col-md-4">
            <div class="card">
                <div class="card-header">
                    회원 1분 거래내역 <small class="ml-2">총 {{ number_format(bcmul(array_sum($daily_rolling_1), 10000)) }}원</small>
                </div>

                <div class="card-body table-responsive" style="max-height: calc(100vh - 220px);">
                    <table class="table table-hover text-nowrap text-center">
                        <colgroup>
                            <col style="width: 160px;">
                        </colgroup>
                        <thead>
                            <tr>
                                <th>회차</th>
                                <th>결과</th>
                            </tr>
                        </thead>

                        <tbody>
                            @forelse ($trades_1 as $rounds)
                                <tr>
                                    <td class="text-left" data-toggle="tooltip" data-placement="bottom" data-html="true" title="{{ (new \Carbon\Carbon('20'.mb_substr($rounds->first()->round, 0, 6)))->addMinutes(mb_substr($rounds->first()->round, 6))->subMinutes(1) }} ~<br>{{ (new \Carbon\Carbon('20'.mb_substr($rounds->first()->round, 0, 6)))->addMinutes(mb_substr($rounds->first()->round, 6)) }}">
                                        {{ mb_substr($rounds->first()->round, 0, 6) }} - {{ mb_substr($rounds->first()->round, 6) }} 회차
                                    </td>
                                    <td class="text-left">
                                        @foreach($rounds as $trade)
                                            @if ($trade->result == 'correct')
                                                <div class="d-inline-block p-1 border border-success rounded text-success" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>실현</span>
                                                </div>
                                            @elseif ($trade->result == 'incorrect')
                                                <div class="d-inline-block p-1 border border-danger rounded text-danger" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>실격</span>
                                                </div>
                                            @elseif ($trade->result == 'unrealized')
                                                <div class="d-inline-block p-1 border border-secondary rounded text-secondary" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>무효</span>
                                                </div>
                                            @else
                                                <div class="d-inline-block p-1 border rounded">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>대기중</span>
                                                </div>
                                            @endif
                                        @endforeach
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="2">거래 내역이 없습니다</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <div class="col-12 col-md-4">
            <div class="card">
                <div class="card-header">
                    회원 3분 거래내역 <small class="ml-2">총 {{ number_format(bcmul(array_sum($daily_rolling_3), 10000)) }}원</small>
                </div>

                <div class="card-body table-responsive" style="max-height: calc(100vh - 220px);">
                    <table class="table table-hover text-nowrap text-center">
                        <colgroup>
                            <col style="width: 160px;">
                        </colgroup>
                        <thead>
                            <tr>
                                <th>회차</th>
                                <th>결과</th>
                            </tr>
                        </thead>

                        <tbody>
                            @forelse ($trades_3 as $rounds)
                                <tr>
                                    <td class="text-left" data-toggle="tooltip" data-placement="bottom" data-html="true" title="{{ (new \Carbon\Carbon('20'.mb_substr($rounds->first()->round, 0, 6)))->addMinutes(mb_substr($rounds->first()->round, 6))->subMinutes(3) }} ~<br>{{ (new \Carbon\Carbon('20'.mb_substr($rounds->first()->round, 0, 6)))->addMinutes(mb_substr($rounds->first()->round, 6)) }}">
                                        {{ mb_substr($rounds->first()->round, 0, 6) }} - {{ mb_substr($rounds->first()->round, 6) }} 회차
                                    </td>
                                    <td class="text-left">
                                        @foreach($rounds as $trade)
                                            @if ($trade->result == 'correct')
                                                <div class="d-inline-block p-1 border border-success rounded text-success" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>실현</span>
                                                </div>
                                            @elseif ($trade->result == 'incorrect')
                                                <div class="d-inline-block p-1 border border-danger rounded text-danger" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>실격</span>
                                                </div>
                                            @elseif ($trade->result == 'unrealized')
                                                <div class="d-inline-block p-1 border border-secondary rounded text-secondary" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>무효</span>
                                                </div>
                                            @else
                                                <div class="d-inline-block p-1 border rounded">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>대기중</span>
                                                </div>
                                            @endif
                                        @endforeach
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="2">거래 내역이 없습니다</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <div class="col-12 col-md-4">
            <div class="card">
                <div class="card-header">
                    회원 5분 거래내역 <small class="ml-2">총 {{ number_format(bcmul(array_sum($daily_rolling_5), 10000)) }}원</small>
                </div>

                <div class="card-body table-responsive" style="max-height: calc(100vh - 220px);">
                    <table class="table table-hover text-nowrap text-center">
                        <colgroup>
                            <col style="width: 160px;">
                        </colgroup>
                        <thead>
                            <tr>
                                <th>회차</th>
                                <th>결과</th>
                            </tr>
                        </thead>

                        <tbody>
                            @forelse ($trades_5 as $rounds)
                                <tr>
                                    <td class="text-left" data-toggle="tooltip" data-placement="bottom" data-html="true" title="{{ (new \Carbon\Carbon('20'.mb_substr($rounds->first()->round, 0, 6)))->addMinutes(mb_substr($rounds->first()->round, 6))->subMinutes(5) }} ~<br>{{ (new \Carbon\Carbon('20'.mb_substr($rounds->first()->round, 0, 6)))->addMinutes(mb_substr($rounds->first()->round, 6)) }}">
                                        {{ mb_substr($rounds->first()->round, 0, 6) }} - {{ mb_substr($rounds->first()->round, 6) }} 회차
                                    </td>
                                    <td class="text-left">
                                        @foreach($rounds as $trade)
                                            @if ($trade->result == 'correct')
                                                <div class="d-inline-block p-1 border border-success rounded text-success" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>실현</span>
                                                </div>
                                            @elseif ($trade->result == 'incorrect')
                                                <div class="d-inline-block p-1 border border-danger rounded text-danger" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>실격</span>
                                                </div>
                                            @elseif ($trade->result == 'unrealized')
                                                <div class="d-inline-block p-1 border border-secondary rounded text-secondary" data-toggle="tooltip" title="보유금: {{ number_format($trade->user_balance) }}원">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>무효</span>
                                                </div>
                                            @else
                                                <div class="d-inline-block p-1 border rounded">
                                                    <strong>{{ $trade->user->name }} ({{ $trade->user->account }})</strong>
                                                    <span>{{ number_format($trade->amount * 10000) }}</span>
                                                    @if ($trade->pick == 'up')
                                                        <span>매수</span>
                                                    @elseif ($trade->pick == 'down')
                                                        <span>매도</span>
                                                    @endif
                                                    <span>대기중</span>
                                                </div>
                                            @endif
                                        @endforeach
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="2">거래 내역이 없습니다</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
