@extends('layouts.branch')

@section('page.name', 'transactions')

@push('scripts')
    <script>
        $(function() {
            let dt = $('#transactions').DataTable({
                processing: true,
                serverSide: true,
                ajax: "{{ $dt_link }}?type={{ $type }}",
                columns: [
                    {data: 'created_at_formatted', name: 'created_at'},
                    {data: 'name_link', name: 'name_link'},
                    {data: 'branch', name: 'branch'},
                    {data: 'type_string', name: 'type'},
                    {data: 'amount_formatted', name: 'amount'},
                    {data: 'info_formatted', name: 'info'},
                    {data: 'status_string', name: 'status'},
                    {data: 'btn_approve', name: 'btn_approve'},
                    {data: 'btn_disapprove', name: 'btn_disapprove'},
                    {data: 'btn_waiting', name: 'btn_waiting'},
                ]
            });

            $('.search').click(function() {
                if ($(this).data('type') == '') {
                    dt.columns(3).search('').draw();
                } else {
                    dt.columns(3).search('^' + $(this).data('type') + '$', true, false).draw();
                }
            });

            $('.datepicker').on('changeDate', function(e) {
                let date = moment(e.date).format('YYYY-MM-DD');
                dt.columns(0).search(date).draw();
            });

            $('#transactions').on('click', '.tx-approve', function(e) {
                e.preventDefault();

                if (!confirm('승인 처리 하시겠습니까?')) {
                    return;
                }

                axios.patch($(this).attr('href'), {
                    status: 'success',
                }).then(function (response) {
                    alert(response.data.message || '승인 처리 되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('승인에 실패하였습니다');
                    }
                });
            });

            $('#transactions').on('click', '.tx-disapprove', function(e) {
                e.preventDefault();

                if (!confirm('취소 처리 하시겠습니까?')) {
                    return;
                }

                axios.patch($(this).attr('href'), {
                    status: 'failed',
                }).then(function (response) {
                    alert(response.data.message || '취소 처리 되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('취소에 실패하였습니다');
                    }
                });
            });

            $('#transactions').on('click', '.tx-waiting', function(e) {
                e.preventDefault();

                if (!confirm('대기 처리 하시겠습니까?')) {
                    return;
                }

                axios.patch($(this).attr('href'), {
                    status: 'waiting',
                }).then(function (response) {
                    alert(response.data.message || '대기 처리 되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('대기에 실패하였습니다');
                    }
                });
            });
        });
    </script>
@endpush

@section('content')
<div class="container-fluid py-3">
    <div class="row">
        <div class="col-12">
            <div class="card mb-3">
                <div class="card-header">
                    입출금 관리
                </div>

                <div class="card-body table-responsive">
                    <div class="mb-3">
                        <div class="form-inline">
                            <button class="btn btn-primary mr-2 search" data-type="deposit">입금</button>
                            <button class="btn btn-danger mr-2 search" data-type="withdraw">출금</button>
                            <button class="btn btn-success mr-2 search" data-type="">전체</button>

                            <input type="text" class="form-control datepicker mr-2" name="date" placeholder="날짜 입력">

                            <button class="btn btn-primary mr-2 search" data-type="deposit_manual">수동입금</button>
                            <button class="btn btn-danger mr-2 search" data-type="withdraw_manual">수동출금</button>
                        </div>
                    </div>

                    <table id="transactions" class="table table-hover text-nowrap text-center">
                        <thead>
                            <tr>
                                <th>날짜</th>
                                <th>회원명</th>
                                <th>소속지점</th>
                                <th>구분</th>
                                <th>금액</th>
                                <th>은행정보</th>
                                <th>상태</th>
                                <th>승인</th>
                                <th>취소</th>
                                <th>대기</th>
                            </tr>
                        </thead>

                        <tbody>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
