@extends('layouts.branch')

@section('page.name', 'unplayed_trades')

@push('scripts')
    <script>
        $(function() {
            $('.btn-add').click(function(e) {
                e.preventDefault();

                if (!confirm('회차 결과 내역을 추가하시겠습니까?')) {
                    return;
                }

                $(this).addClass('disabled');

                axios.post("{{ route('branch.trade.create') }}", {
                    symbol: '{{ $symbol }}',
                    type: $('select option:selected').data('type'),
                    round: $('select option:selected').data('round'),
                    open: $('#open').val(),
                    close: $('#close').val()
                }).then(function (response) {
                    alert(response.data.message || '내역이 추가되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('추가에 실패하였습니다');
                    }
                });
            });
        });
    </script>
@endpush

@section('content')
<div class="container-fluid py-3">
    <div class="mb-3 text-right">
        <div class="btn-group">
            <a href="?symbol=BTCUSDT" class="btn {{ $symbol == 'BTCUSDT' ? 'btn-primary' : 'btn-light' }}">BTCUSDT</a>
            <a href="?symbol=GBPAUD" class="btn {{ $symbol == 'GBPAUD' ? 'btn-primary' : 'btn-light' }}">GBPAUD</a>
        </div>
    </div>

    <div class="row">
        <div class="col-12 col-md-4">
            <div class="card mb-3">
                <div class="card-header">
                    미진행 회차 추가
                </div>

                <div class="card-body">
                    <div class="form-group">
                        <select class="custom-select" name="round">
                            @forelse ($unplayed_trades as $betting)
                                @php
                                    if (isset($round[$betting->type]) && $round[$betting->type] == $betting->round) {
                                        continue;
                                    } else {
                                        $round[$betting->type] = $betting->round;
                                    }
                                @endphp
                                <option data-type="{{ $betting->type }}" data-round="{{ $betting->round }}">{{ $betting->type }}분 - {{ mb_substr($betting->round, 0, 6) }} - {{ mb_substr($betting->round, 6) }}</option>
                            @empty
                                <option>미진행 회차가 없습니다</option>
                            @endforelse
                        </select>
                    </div>

                    <div class="form-group">
                        <label>시가</label>
                        <input type="text" class="form-control" id="open">
                    </div>

                    <div class="form-group">
                        <label>종가</label>
                        <input type="text" class="form-control" id="close">
                    </div>

                    <div class="form-group">
                        <button type="submit" class="btn btn-success btn-add">내역 수동추가</button>
                    </div>
                </div>
            </div>
        </div>

        <div class="col-12 col-md-8">
            <div class="card mb-3">
                <div class="card-header">
                    수동 추가내역
                </div>

                <div class="card-body">
                    <table class="table">
                        <thead>
                            <tr>
                                <td>회차정보</td>
                                <td>시가</td>
                                <td>종가</td>
                                <td>결과</td>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse ($manual_inserts as $game_result)
                                <tr>
                                    <td>{{ $game_result->type }}분 - {{ mb_substr($game_result->round, 0, 6) }} - {{ mb_substr($game_result->round, 6) }}</td>
                                    <td>{{ $game_result->open }}</td>
                                    <td>{{ $game_result->close }}</td>
                                    <td>{{ $game_result->result == 'unrealized' ? '무효' : ($game_result->result == 'up' ? '상승' : '하락') }}</td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="3">추가 내역이 없습니다</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
