@extends('layouts.branch')

@section('page.name', 'user')

@push('scripts')
    <script>
        $(function() {
            $('.update_user').click(function (e) {
                e.preventDefault();

                if (!confirm('회원 정보를 수정하시겠습니까?')) {
                    return;
                }

                axios.patch($(this).attr('href'), {
                    status: $(this).data('status')
                }).then(function (response) {
                    alert(response.data.message || '회원 정보가 수정되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('수정에 실패하였습니다');
                    }
                });
            });

            $('.form-first').submit(function (e) {
                e.preventDefault();

                if (!confirm('회원 정보를 수정하시겠습니까?')) {
                    return;
                }

                axios.patch($(this).attr('action'), {
                    password: $('#password').val(),
                    bank_info: $('#bank_info').val(),
                    memo: $('#memo').val()
                    // reset_bank: $('#reset_bank').prop('checked')
                }).then(function (response) {
                    alert(response.data.message || '회원 정보가 수정되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('수정에 실패하였습니다');
                    }
                });
            });

            $('.form-branch').submit(function (e) {
                e.preventDefault();

                if (!confirm('소속 지점을 수정하시겠습니까?')) {
                    return;
                }

                axios.patch($(this).attr('action'), {
                    branch: $('#branch').val()
                }).then(function (response) {
                    alert(response.data.message || '소속 지점이 수정되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('수정에 실패하였습니다');
                    }
                });
            });

            $('.form-tx').submit(function (e) {
                e.preventDefault();

                if (!confirm('회원 정보를 수정하시겠습니까?')) {
                    return;
                }

                axios.patch($(this).attr('action'), {
                    amount: $(this).find('.amount').val(),
                    tx_type: $(this).find('.tx_type').val()
                }).then(function (response) {
                    alert(response.data.message || '회원 정보가 수정되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        alert(error.response.data.message);
                    } else {
                        alert('수정에 실패하였습니다');
                    }
                });
            });
        });
    </script>
@endpush

@section('content')
<div class="container-fluid py-3">
    <div class="row">
        <div class="col-12 col-md-6 offset-md-3">
            <div class="card mb-3">
                <div class="card-header">
                    회원 정보 - {{ $user->name }}
                </div>

                <div class="card-body table-responsive">
                    <table class="table table-sm table-hover text-nowrap">
                        <colgroup>
                            <col style="width: 120px;">
                        </colgroup>
                        <tbody>
                            <tr>
                                <th class="text-center">회원명</th>
                                <td class="text-right">{{ $user->name }} ({{ $user->account }})</td>
                            </tr>
                            <tr>
                                <th class="text-center">소속 지점</th>
                                @if ($user->parentBranch)
                                    <td class="text-right">{{ $user->parentBranch->branchUser->name }} ({{ $user->parentBranch->branchUser->account }})</td>
                                @else
                                    <td class="text-right">없음</td>
                                @endif
                            </tr>
                            <tr>
                                <th class="text-center">가입일</th>
                                <td class="text-right">{{ $user->created_at }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">마지막 로그인</th>
                                <td class="text-right">{{ $user->lastLoginAt() }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">마지막 로그인 아이피</th>
                                <td class="text-right">{{ $user->lastLoginIp() }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">계좌 정보</th>
                                <td class="text-right">{{ $user->bank_info ? (Auth::user()->isMaster() ? $user->bank_info : mb_substr($user->bank_info, 0, -4).'****') : '미등록' }}</td>
                            </tr>
                            <tr>
                                <th class="text-center">입금액</th>
                                <td class="text-right">{{ number_format($user->transactions() ? $user->transactions()->whereType('deposit')->whereStatus('success')->sum('amount') : 0)}} 원</td>
                            </tr>
                            <tr>
                                <th class="text-center">출금액</th>
                                <td class="text-right">{{ number_format($user->transactions() ? $user->transactions()->whereType('withdraw')->whereStatus('success')->sum('amount') : 0)}} 원</td>
                            </tr>
                            <tr>
                                <th class="text-center">총 거래액</th>
                                <td class="text-right">{{ number_format($user->bettings() ? bcmul($user->bettings()->whereNotNull('result')->where('result', '!=', 'unrealized')->sum('amount'), 10000) : 0) }} 원 ({{ $user->bettings()->whereNotNull('result')->where('result', '!=', 'unrealized')->count() }}회)</td>
                            </tr>
                            <tr>
                                <th class="text-center">거래 손익</th>
                                <td class="text-right">{{ number_format($user->bettings() ? bcmul($user->bettings()->whereResult('correct')->sum('amount') - $user->bettings()->whereResult('incorrect')->sum('amount'), 10000) : 0) }} 원</td>
                            </tr>
                            <tr>
                                <th class="text-center">보유 금액</th>
                                <td class="text-right">{{ number_format($user->balance) }} 원</td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>

            @if (Auth::user()->id != $user->id)
                <div class="card mb-3">
                    <div class="card-header">
                        정보 수정
                    </div>

                    <div class="card-body">
                        @if (Auth::user()->isMaster())
                            <form action="{{ route('branch.user.update', $user) }}" method="POST" class="form-first">
                                @csrf
                                @method('PATCH')

                                <div class="form-group">
                                    <label>비밀번호</label>
                                    <input type="password" class="form-control" id="password" name="password">
                                </div>

                                <div class="form-group">
                                    <label>계좌정보</label>
                                    <input type="text" class="form-control" id="bank_info" name="bank_info" value="{{ $user->bank_info }}">
                                </div>

                                <div class="form-group">
                                    <label>메모</label>
                                    <textarea rows="10" class="form-control" id="memo" name="memo">{{ $user->memo }}</textarea>
                                </div>

                                <!-- <div class="custom-control custom-switch">
                                    <input type="checkbox" class="custom-control-input" name="reset_bank" id="reset_bank">
                                    <label class="custom-control-label" for="reset_bank">계좌정보 초기화</label>
                                </div> -->

                                <div class="text-right">
                                    <button type="submit" class="btn btn-success">수정</button>
                                </div>
                            </form>

                            <hr>

                            <form action="{{ route('branch.user.update', $user) }}" method="POST" class="form-branch">
                                @csrf
                                @method('PATCH')

                                <div class="form-group">
                                    <label>지점</label>
                                    <input type="text" class="form-control" id="branch" name="branch" value="{{ $user->parentBranch ? $user->parentBranch->branchUser->name : '' }}">
                                </div>

                                <div class="text-right">
                                    <button type="submit" class="btn btn-success">수정</button>
                                </div>
                            </form>

                            <hr>
                        @endif

                        <form action="{{ route('branch.user.update', $user) }}" method="POST" class="form-tx">
                            @csrf
                            @method('PATCH')
                            <input type="hidden" name="tx_type" class="tx_type" value="deposit">

                            <div class="form-group">
                                <label>금액</label>
                                <input type="text" class="form-control amount" name="amount">
                            </div>

                            <div class="text-right">
                                <button type="submit" class="btn btn-success">입금내역 추가</button>
                            </div>
                        </form>

                        @if (Auth::user()->isMaster())
                            <hr>

                            <form action="{{ route('branch.user.update', $user) }}" method="POST" class="form-tx">
                                @csrf
                                @method('PATCH')
                                <input type="hidden" name="tx_type" class="tx_type" value="withdraw">

                                <div class="form-group">
                                    <label>금액</label>
                                    <input type="text" class="form-control amount" name="amount">
                                    <small>출금 처리된 금액은 소멸됩니다</small>
                                </div>

                                <div class="text-right">
                                    <button type="submit" class="btn btn-danger">출금내역 추가</button>
                                </div>
                            </form>
                        @endif
                    </div>
                </div>
            @endif

            <div class="mb-3">
                <div class="d-flex justify-content-around">
                    <a href="{{ route('branch.user.trade.list', $user->id) }}" class="btn btn-outline-primary">거래내역</a>
                    <a href="{{ route('branch.user.tx.list', $user->id) }}" class="btn btn-outline-primary">입출금내역</a>
                    <a href="{{ route('branch.note.form', ['user_id' => $user->id]) }}" class="btn btn-outline-success">쪽지 전송</a>
                    @if (Auth::user()->isMaster())
                        @if ($user->status == 'unregistered')
                            <a href="{{ route('branch.user.update', $user->id) }}" class="btn btn-outline-danger update_user" data-status="normal">탈퇴 해제</a>
                        @else
                            @if ($user->status == 'normal')
                                <a href="{{ route('branch.user.update', $user->id) }}" class="btn btn-outline-danger update_user" data-status="suspended">일시정지</a>
                            @elseif ($user->status == 'suspended')
                                <a href="{{ route('branch.user.update', $user->id) }}" class="btn btn-outline-danger update_user" data-status="normal">일시정지 해제</a>
                            @endif
                            <a href="{{ route('branch.user.update', $user->id) }}" class="btn btn-outline-danger update_user" data-status="unregistered">탈퇴</a>
                        @endif
                    @endif
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
