@extends('layouts.app')

@section('page.name', 'contacts')

@push('scripts')
    @if (Auth::user()->isMaster())
        <script>
            $(function() {
                $('.delete-notice').click(function(e) {
                    e.preventDefault();

                    if (!confirm('정말로 삭제하시겠습니까?')) {
                        return
                    }

                    axios.delete($(this).attr('href')).then(function (response) {
                        alert(response.data.message || '공지사항이 삭제되었습니다');
                        location.reload();
                    }).catch(function (error) {
                        if (error.response && error.response.data) {
                            alert(error.response.data.message);
                        } else {
                            alert('삭제에 실패하였습니다');
                        }
                    });
                });
            });
        </script>
    @endif
@endpush

@section('content')
<div class="container my-3">
    <div class="card mb-3">
        <div class="card-body">
            <h5 class="card-title">1:1 문의 작성</h5>
            <form action="{{ route('contact.create') }}" method="POST">
                @csrf

                <p>
                    {!! nl2br(DB::table('config')->where('key', 'contact_info')->first()->value ?? '') !!}
                </p>

                <div class="form-group">
                    <label>제목</label>
                    <input type="text" name="subject" class="form-control" required>
                </div>

                <div class="form-group">
                    <label>내용</label>
                    <textarea name="content" class="form-control" rows="10" required></textarea>
                </div>

                <div class="text-right">
                    <button type="submit" class="btn btn-success">작성</button>
                </div>
            </form>
        </div>
    </div>

    <div class="card">
        <div class="card-body">
            <h5 class="card-title">1:1 문의 내역</h5>
            <div class="table-responsive">
                <table class="table text-center">
                    <colgroup>
                        <col>
                        <col style="width: 120px">
                        <col style="width: 200px">
                    </colgroup>
                    <thead>
                        <tr>
                            <th>제목</th>
                            <th>상태</th>
                            <th>시간</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse($contacts as $contact)
                            <tr>
                                <td class="text-left"><a href="{{ route('contact.show', $contact->id) }}">{{ $contact->subject }}</a></td>
                                @if ($contact->isReplied())
                                    <td class="text-success">답변됨</td>
                                @else
                                    <td class="text-danger">답변안됨</td>
                                @endif
                                <td>{{ $contact->created_at->format('Y-m-d H:i:s') }}</td>
                            </tr>
                        @empty
                            <tr>
                                <td colspan="3">문의 내역이 없습니다</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>
@endsection