<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="csrf-token" content="{{ csrf_token() }}">

    <title>{{ config('app.name') }}</title>

    <link rel="dns-prefetch" href="//cdnjs.cloudflare.com">

    <link href="{{ asset('css/app.css') }}" rel="stylesheet">
    @stack('stylesheets')
</head>
<body>
    <div id="app">
        <nav class="navbar navbar-expand-lg navbar-dark sticky-top" style="background-color: #000000;">
            <div class="container">
                <a class="navbar-brand" href="{{ route('main') }}">
                    <img src="{{ asset('/img/logo.png') }}" style="max-height: 32px;">
                </a>

                <button class="navbar-toggler ml-auto mr-2" type="button" data-toggle="collapse" data-target="#navbarContent">
                    <span class="navbar-toggler-icon"></span>
                </button>

                <div class="collapse navbar-collapse" id="navbarContent">
                    <ul class="navbar-nav mr-auto">
                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('trade.index', ['symbol' => 'BTCUSDT']) }}"><span>코인거래소</span></a>
                        </li>

                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('trade.index', ['symbol' => 'GBPAUD']) }}"><span>FX거래소</span></a>
                        </li>

                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('trade.list') }}"><span>거래내역</span></a>
                        </li>

                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('tx.index') }}"><span>충전/환전</span></a>
                        </li>

                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('contact.list') }}"><span>1:1 문의하기</span></a>
                        </li>

                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('notice.list') }}"><span>공지사항</span></a>
                        </li>
                    </ul>

                    <ul class="navbar-nav ml-auto">
                        @auth
                            <li class="nav-item dropdown">
                                <a class="nav-link dropdown-toggle" href="#" data-toggle="dropdown">
                                    <span>{{ Auth::user()->name }} 님</span>
                                    @if (Auth::user()->receivedNotes()->whereNull('readed_at')->exists())
                                        <span class="badge badge-pill badge-danger">{{ Auth::user()->receivedNotes()->whereNull('readed_at')->count() }}</span>
                                    @endif
                                </a>
                                <div class="dropdown-menu">
                                    <a class="dropdown-item" href="{{ route('note.list') }}">
                                        받은 쪽지함
                                        @if (Auth::user()->receivedNotes()->whereNull('readed_at')->exists())
                                            <span class="badge badge-pill badge-danger">{{ Auth::user()->receivedNotes()->whereNull('readed_at')->count() }}</span>
                                        @endif
                                    </a>
                                    <a class="dropdown-item" href="{{ route('password.change') }}">비밀번호 변경</a>
                                </div>
                            </li>

                            <span class="navbar-text mx-3"><span>{{ number_format(Auth::user()->balance) }}</span>원 보유중</span>

                            <li class="nav-item">
                                <a class="nav-link" href="{{ route('logout') }}" onclick="event.preventDefault(); document.getElementById('logout-form').submit();">
                                    <span>로그아웃</span>
                                </a>

                                <form id="logout-form" action="{{ route('logout') }}" method="POST" style="display: none;">
                                    @csrf
                                </form>
                            </li>

                            <li class="nav-item">
                                @if (Auth::user()->isBranch() || Auth::user()->isMaster())
                                    <a class="nav-link" href="{{ route('branch.main') }}"><span>지점 관리</span></a>
                                @endif
                            </li>
                        @else
                            <li class="nav-item">
                                <a class="nav-link" href="{{ route('login') }}"><span>로그인</span></a>
                            </li>

                            <li class="nav-item">
                                <a class="nav-link" href="{{ route('register') }}"><span>회원가입</span></a>
                            </li>
                        @endif
                    </ul>
                </div>
            </div>
        </nav>

        <main class="user @hasSection('page.name') page-@yield('page.name') @endif bg-lightgray">
            <div class="d-flex justify-content-center">
                @yield('content')
            </div>
        </main>
    </div>

    <footer class="py-5 bg-dark text-light">
        <div class="container">
            <p>{{ config('app.name') }}은 투자 정보를 제공하는 업체로서 모든 투자의 책임은 투자자 본인에게 있습니다.</p>
            <p>
                주소: 서울특별시 강남구 테헤란로 20길 18<br>
                사업자등록번호: 660-10-01305 | 통신판매업등록번호: 제 2019-서울강남-02664
            </p>
            <p>Copyright &copy; 2020 {{ config('app.name') }}. All rights reserved.</p>
        </div>
    </footer>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.14.0/js/fontawesome.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.14.0/js/all.min.js"></script>
    <script src="https://js.pusher.com/6.0/pusher.min.js"></script>
    <script src="{{ asset('/js/app.js') }}"></script>
    @if (session()->has('message'))
        <div id="toast" class="toast" style="position: absolute; bottom: 10px; right: 10px;">
            <div class="toast-header">
                <i class="far fa-bell mr-2"></i>
                <strong class="mr-auto">알림</strong>
                <button type="button" class="ml-2 mb-1 close" data-dismiss="toast">
                    <span>&times;</span>
                </button>
            </div>
            <div class="toast-body">
                {{ session()->get('message') }}
            </div>
        </div>

        <script>
            $(function() {
                $("#toast").toast({
                    'delay': 5000
                }).toast('show');
            });
        </script>
    @endif
    @stack('scripts')
</body>
</html>
