@extends('layouts.app')

@section('page.name', 'trade')

@push('scripts')
    <script>
        $(function() {
            let symbol = '{{ $symbol }}';
            let minutes = {{ $minutes }};
            let unit_max = {
                1: 10,
                3: 25,
                5: 30
            }[minutes];
            let bet_units = {
                'up': {
                    '0.5': 0,
                    '1.0': 0,
                    '5.0': 0,
                    '10': 0,
                },
                'down': {
                    '0.5': 0,
                    '1.0': 0,
                    '5.0': 0,
                    '10': 0,
                }
            };
            let unit_total = {
                'up': 0,
                'down': 0
            };
            let decimal_length = {{ 8 - $config['decimal_length'] }};

            $('.bet-increase').click(function() {
                let type = $(this).data('pick');
                let bet_unit = $(this).data('bet-unit');

                if (bet_units[type][bet_unit] >= unit_max) {
                    return;
                }

                bet_units[type][bet_unit]++;
                updateSummary();
            });

            $('.bet-decrease').click(function() {
                let type = $(this).data('pick');
                let bet_unit = $(this).data('bet-unit');

                if (bet_units[type][bet_unit] <= 0) {
                    return;
                }

                bet_units[type][bet_unit]--;
                updateSummary();
            });

            $('.bet-min').click(function() {
                let type = $(this).data('pick');
                let bet_unit = $(this).data('bet-unit');

                bet_units[type][bet_unit] = 0;
                updateSummary();
            });

            $('.bet-max').click(function() {
                let type = $(this).data('pick');
                let bet_unit = $(this).data('bet-unit');

                bet_units[type][bet_unit] = unit_max;
                updateSummary();
            });

            $('.bet-all-min').click(function() {
                for (let unit in bet_units['up']) {
                    bet_units['up'][unit] = 0;
                    bet_units['down'][unit] = 0;
                }
                updateSummary();
            });

            $('.bet-all-max').click(function() {
                for (let unit in bet_units['up']) {
                    bet_units['up'][unit] = unit_max;
                    bet_units['down'][unit] = unit_max;
                }
                updateSummary();
            });

            function updateSummary() {
                unit_total = {
                    'up': 0,
                    'down': 0,
                };

                for (let unit in bet_units['up']) {
                    unit_total['up'] += bet_units['up'][unit] * unit;
                    $('.badge-summary[data-pick="up"][data-bet-unit="' + unit + '"]').text(bet_units['up'][unit]);
                }

                for (let unit in bet_units['down']) {
                    unit_total['down'] += bet_units['down'][unit] * unit;
                    $('.badge-summary[data-pick="down"][data-bet-unit="' + unit + '"]').text(bet_units['down'][unit]);
                }

                $('#bet_summary_up').html('<i class="fas fa-won-sign"></i> ' + (unit_total['up'] * 10000).toLocaleString() + '<small class="d-block text-secondary">' + unit_total['up'] + ' LOT</small>');
                $('#bet_summary_down').html('<i class="fas fa-won-sign"></i> ' + (unit_total['down'] * 10000).toLocaleString() + '<small class="d-block text-secondary">' + unit_total['down'] + ' LOT</small>');
            }

            $('.btn-bet').click(function() {
                updateSummary();

                let type = $(this).data('pick');

                let pick_text = (type == 'up') ? '매수' : '매도';

                if (!confirm('주문 확인\n' + pick_text + ' / ' +  unit_total[type] + ' LOT' + '\n\n주문 하시겠습니까?')) {
                    return;
                }

                axios.post("{{ route('trade.bet', ['symbol' => $symbol, 'minutes' => $minutes]) }}", {
                    amount: unit_total[type],
                    pick: type,
                }).then(function (response) {
                    alert(response.data.message || '주문이 완료되었습니다');
                    location.reload();
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        if (error.response.data.message) {
                            alert(error.response.data.message);
                        } else {
                            alert ('주문에 실패하였습니다 (' + error.response.status + ')');
                        }
                    } else {
                        alert('주문에 실패하였습니다');
                    }
                });
            });

            function getInformation() {
                axios.get("{{ route('trade.info', ['symbol' => $symbol, 'minutes' => $minutes]) }}").then(function (response) {
                    setMomentOffset(response.data.time);

                    $('#round_info').html('<b title="' + response.data.playing_round_time_range.join(' ~ ') + '" data-placement="bottom" data-toggle="tooltip">' +
                        parseInt(response.data.playing_round.substring(6)) + ' 회차</b> 거래 진행중 / <b title="' + response.data.bet_round_time_range.join(' ~ ') + '" data-placement="bottom" data-toggle="tooltip">' +
                        parseInt(response.data.bet_round.substring(6)) + ' 회차</b> 투표중');
                    $('#round_remain').data('seconds', response.data.bet_close);

                    $('[data-toggle="tooltip"]').tooltip();

                    if (response.data.bet_close <= 0) {
                        $('#round_remain').html('<b>마감</b>');
                    } else {
                        $('#round_remain').html(parseInt(response.data.bet_close / 60).toString().padStart(2, '0') + ':' + (response.data.bet_close % 60).toString().padStart(2, '0'));
                    }

                    if (response.data.maintenance_mode) {
                        $('.bet-row').addClass('d-none');
                        $('#maintenance_alert').addClass('d-table-row').removeClass('d-none');
                    } else {
                        $('.bet-row').removeClass('d-none');
                        $('#maintenance_alert').addClass('d-none').removeClass('d-table-row');
                    }
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        if (error.response.data.message) {
                            alert(error.response.data.message);
                        } else {
                            alert ('정보를 가져오지 못했습니다 (' + error.response.status + ')');
                        }
                    } else {
                        alert('정보를 가져오지 못했습니다');
                    }
                });
            }

            function getResults(amount = 1) {
                axios.get("{{ route('trade.results.json', ['symbol' => $symbol, 'minutes' => $minutes]) }}", {params: {amount: amount}}).then(function (response) {
                    let reversed = response.data.reverse();
                    for(let i in reversed) {
                        let result;

                        if (reversed[i].result == 'up') {
                            result = '<td><i class="fas fa-arrow-up text-success"></i> <span>매수</span></td>';
                        } else if (reversed[i].result == 'down') {
                            result = '<td><i class="fas fa-arrow-down text-danger"></i> <span>매도</span></td>';
                        } else if (reversed[i].result == 'unrealized') {
                            result = '<td><i class="fas fa-minus text-secondary"></i> <span>무효</span></td>';
                        }

                        $('#results tbody').prepend('<tr>' +
                            '<td>' + parseInt(reversed[i].round.toString().substring(6)) + '</td>' +
                            '<td>' + reversed[i].open.toString().slice(0, -decimal_length) + '</td>' +
                            '<td>' + reversed[i].close.toString().slice(0, -decimal_length) + '</td>' +
                            result +
                        '</tr>');
                    }
                }).catch(function (error) {
                    if (error.response && error.response.data) {
                        if (error.response.data.message) {
                            alert(error.response.data.message);
                        } else {
                            alert ('정보를 가져오지 못했습니다 (' + error.response.status + ')');
                        }
                    } else {
                        alert('정보를 가져오지 못했습니다');
                    }
                });
            }

            getInformation();
            getResults(50);

            function setMomentOffset(serverTime) {
                var offset = new Date(serverTime).getTime() - Date.now();
                moment.now = function() {
                    return offset + Date.now();
                }
            }

            setInterval(function() {
                $('#time').text(moment().format('YYYY-MM-DD HH:mm:ss'));

                let seconds = $('#round_remain').data('seconds');
                seconds--;
                if (seconds <= 0) {
                    $('#round_remain').html('<b>마감</b>');
                    $('#remain_progressbar').css('width', '0');
                } else {
                    $('#round_remain').data('seconds', seconds);
                    $('#round_remain').html(parseInt(seconds / 60).toString().padStart(2, '0') + ':' + (seconds % 60).toString().padStart(2, '0'));
                    $('#remain_progressbar').css('width', (seconds / (minutes * 60) * 100) + '%');
                }
            }, 1000);

            Echo.channel('trade.' + symbol + '.' + minutes)
                .listen('GameResult', (data) => {
                    getInformation();
                    getResults();
                    $('#result_board').html(
                        '<div>' +
                            '<small class="d-block">' +
                                parseInt(data.round.substring(6)) + ' 회차' +
                            '</small>' +
                            '<strong class="' + (data.result == 'up' ? 'text-success' : (data.result == 'down' ? 'text-danger' : '')) +'" style="font-size: 1.875rem;">' +
                                (data.result == 'up' ? '매수' : (data.result == 'down' ? '매도' : '무효')) +
                            '</strong>' +
                        '</div>'
                    );

                    if (data.result == 'up') {
                        $('#result_board').addClass('border-success').removeClass('border-danger');
                    } else if (data.result == 'down') {
                        $('#result_board').addClass('border-danger').removeClass('border-success');
                    }

                    setTimeout(function() {
                        $('#result_board').removeClass('border-success border-danger');
                    }, 100);

                    setTimeout(function() {
                        $('#result_board').text('결과 대기중');
                    }, 10000);
                });

            @if ($config['chart_type'] == 'self')
                $('#tradingview iframe').height($('#tradingview iframe').parents('.tradingview-widget-container').parent().height());
            @endif
        });
    </script>
@endpush

@section('content')
<div class="container-fluid pt-3">
    <div class="row">
        <div class="col-12 col-md-4 mb-3">
            <a href="{{ route('trade.index', ['symbol' => $symbol, 'minutes' => 1]) }}" class="btn {{ $minutes == 1 ? 'btn-info' : 'btn-outline-info text-dark' }} w-100"><i class="fab fa-bitcoin"></i> <span>1분 거래소</span></a>
        </div>
        <div class="col-12 col-md-4 mb-3">
            <a href="{{ route('trade.index', ['symbol' => $symbol, 'minutes' => 3]) }}" class="btn {{ $minutes == 3 ? 'btn-info' : 'btn-outline-info text-dark' }} w-100"><i class="fab fa-bitcoin"></i> <span>3분 거래소</span></a>
        </div>
        <div class="col-12 col-md-4 mb-3">
            <a href="{{ route('trade.index', ['symbol' => $symbol, 'minutes' => 5]) }}" class="btn {{ $minutes == 5 ? 'btn-info' : 'btn-outline-info text-dark' }} w-100"><i class="fab fa-bitcoin"></i> <span>5분 거래소</span></a>
        </div>
    </div>

    <div class="row">
        <div class="col-12 col-md-6 mb-3">
            <div class="tradingview-widget-container">
                @if ($config['chart_type'] == 'widget')
                    <div id="tradingview" style="min-height: 400px;"></div>
                    <script type="text/javascript" src="https://s3.tradingview.com/tv.js"></script>
                    <script type="text/javascript">
                        new TradingView.widget({
                            "width": "100%",
                            "height": "100%",
                            "symbol": "BINANCE:BTCUSDT",
                            "interval": "{{ $minutes }}",
                            "timezone": "Asia/Seoul",
                            "theme": "light",
                            "style": "1",
                            "locale": "kr",
                            "toolbar_bg": "#f1f3f6",
                            "enable_publishing": false,
                            "save_image": false,
                            "container_id": "tradingview",
                            "studies": [
                                "MASimple@tv-basicstudies",
                                "BB@tv-basicstudies"
                            ]
                        });
                    </script>
                @else
                    <div id="tradingview" style="min-height: 400px;"></div>
                    <script type="text/javascript" src="/charting_library/charting_library/charting_library.js"></script>
                    <script type="text/javascript" src="/charting_library/datafeeds/udf/dist/polyfills.js"></script>
                    <script type="text/javascript" src="/charting_library/datafeeds/udf/dist/bundle.js"></script>
                    <script type="text/javascript">
                        let tv_widget = new TradingView.widget({
                            "width": "100%",
                            "height": "100%",
                            "symbol": "GBPAUD",
                            "interval": "{{ $minutes }}",
                            "timezone": "Asia/Seoul",
                            "theme": "light",
                            "style": "1",
                            "locale": "ko",
                            "toolbar_bg": "#f1f3f6",
                            "enable_publishing": false,
                            "container_id": "tradingview",
                            library_path: "/charting_library/charting_library/",
                            datafeed: new Datafeeds.UDFCompatibleDatafeed("https://udf.bitqzone.com", 1000),
                            disabled_features: ["left_toolbar", "timeframes_toolbar"],
                            enabled_features: [""]
                        });

                        tv_widget.onChartReady(() => {
                            tv_widget.chart().createStudy('Moving Average', false, true);
                            tv_widget.chart().createStudy('Bollinger Bands', false, true);
                        });
                    </script>
                @endif
            </div>
        </div>

        <div class="col-12 col-md-6 mb-3">
            <div class="alert alert-primary d-flex justify-content-between" role="alert">
                <span style="min-width: 70px;">현재 시간</span>
                <div class="text-right">
                    <i class="far fa-clock"></i>
                    <span id="time"><div class="spinner-border spinner-border-sm"></div></span>
                </div>
            </div>

            <div class="alert alert-primary d-flex justify-content-between" role="alert">
                <span style="min-width: 70px;">회차 정보</span>
                <div class="text-right">
                    <span id="round_info"><div class="spinner-border spinner-border-sm"></div></span>
                </div>
            </div>

            <div class="bg-light p-4 border rounded text-center position-relative">
                <div class="row">
                    <div class="col-12 col-lg-4 position-relative">
                        <table class="table">
                            <tbody>
                                <tr>
                                    <th>남은 계약시간</th>
                                    <td><span id="round_remain"><div class="spinner-border spinner-border-sm"></div></span></td>
                                </tr>
                                <tr>
                                    <td colspan="2">
                                        <div class="progress">
                                            <div id="remain_progressbar" class="progress-bar progress-bar-striped progress-bar-animated" style="width: 0"></div>
                                        </div>
                                    </td>
                                </tr>
                            </tbody>
                        </table>

                        <div id="result_board" class="d-flex justify-content-center align-items-center border rounded mb-3" style="height: 120px;">결과 대기중</div>

                        <table class="table">
                            <tbody>
                                <tr>
                                    <th>종목</th>
                                    <td>{{ $config['description'] }} {{ $minutes }}분</td>
                                </tr>
                                <tr>
                                    <th>보유금액</th>
                                    <td><span id="balance">{{ number_format(Auth::user()->balance) }}</span> 원</td>
                                </tr>
                                <tr>
                                    <th>회원명</th>
                                    <td>{{ Auth::user()->name }}</td>
                                </tr>
                            </tbody>
                        </table>
                    </div>

                    <div class="col-12 col-lg-8">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>수량</th>
                                    <th>매수</th>
                                    <th>매도</th>
                                </tr>
                            </thead>
                            <tbody>
                                <tr>
                                    <td>0.5 LOT</td>
                                    <td>
                                        <button data-bet-unit="0.5" data-pick="up" class="btn btn-success bet-unit bet-increase" style="width: 110px;">5,000 <span class="badge badge-light badge-summary" data-bet-unit="0.5" data-pick="up">0</span></button>
                                        <button data-bet-unit="0.5" data-pick="up" class="btn btn-outline-success font-weight-bold bet-max mt-1 mt-sm-0">MAX</button>
                                    </td>
                                    <td>
                                        <button data-bet-unit="0.5" data-pick="down" class="btn btn-danger bet-unit bet-increase" style="width: 110px;">5,000 <span class="badge badge-light badge-summary" data-bet-unit="0.5" data-pick="down">0</span></button>
                                        <button data-bet-unit="0.5" data-pick="down" class="btn btn-outline-danger font-weight-bold bet-max mt-1 mt-sm-0">MAX</button>
                                    </td>
                                </tr>
                                <tr>
                                    <td>1 LOT</td>
                                    <td>
                                        <button data-bet-unit="1.0" data-pick="up" class="btn btn-success bet-unit bet-increase" style="width: 110px;">10,000 <span class="badge badge-light badge-summary" data-bet-unit="1.0" data-pick="up">0</span></button>
                                        <button data-bet-unit="1.0" data-pick="up" class="btn btn-outline-success font-weight-bold bet-max mt-1 mt-sm-0">MAX</button>
                                    </td>
                                    <td>
                                        <button data-bet-unit="1.0" data-pick="down" class="btn btn-danger bet-unit bet-increase" style="width: 110px;">10,000 <span class="badge badge-light badge-summary" data-bet-unit="1.0" data-pick="down">0</span></button>
                                        <button data-bet-unit="1.0" data-pick="down" class="btn btn-outline-danger font-weight-bold bet-max mt-1 mt-sm-0">MAX</button>
                                    </td>
                                </tr>
                                <tr>
                                    <td>5 LOT</td>
                                    <td>
                                        <button data-bet-unit="5.0" data-pick="up" class="btn btn-success bet-unit bet-increase" style="width: 110px;">50,000 <span class="badge badge-light badge-summary" data-bet-unit="5.0" data-pick="up">0</span></button>
                                        <button data-bet-unit="5.0" data-pick="up" class="btn btn-outline-success font-weight-bold bet-max mt-1 mt-sm-0">MAX</button>
                                    </td>
                                    <td>
                                        <button data-bet-unit="5.0" data-pick="down" class="btn btn-danger bet-unit bet-increase" style="width: 110px;">50,000 <span class="badge badge-light badge-summary" data-bet-unit="5.0" data-pick="down">0</span></button>
                                        <button data-bet-unit="5.0" data-pick="down" class="btn btn-outline-danger font-weight-bold bet-max mt-1 mt-sm-0">MAX</button>
                                    </td>
                                </tr>
                                <tr>
                                    <td>10 LOT</td>
                                    <td>
                                        <button data-bet-unit="10" data-pick="up" class="btn btn-success bet-unit bet-increase" style="width: 110px;">100,000 <span class="badge badge-light badge-summary" data-bet-unit="10" data-pick="up">0</span></button>
                                        <button data-bet-unit="10" data-pick="up" class="btn btn-outline-success font-weight-bold bet-max mt-1 mt-sm-0">MAX</button>
                                    </td>
                                    <td>
                                        <button data-bet-unit="10" data-pick="down" class="btn btn-danger bet-unit bet-increase" style="width: 110px;">100,000 <span class="badge badge-light badge-summary" data-bet-unit="10" data-pick="down">0</span></button>
                                        <button data-bet-unit="10" data-pick="down" class="btn btn-outline-danger font-weight-bold bet-max mt-1 mt-sm-0">MAX</button>
                                    </td>
                                </tr>

                                <tr>
                                    <td>신청금액</td>
                                    <td><strong id="bet_summary_up" class="text-success"><i class="fas fa-won-sign"></i> 0<small class="d-block text-secondary">0 LOT</small></strong></td>
                                    <td><strong id="bet_summary_down" class="text-danger"><i class="fas fa-won-sign"></i> 0<small class="d-block text-secondary">0 LOT</small></strong></td>
                                </tr>

                                <tr>
                                    <td></td>
                                    <td>
                                        <button class="btn btn-outline-primary bet-all-min w-100" style="width: 110px;">초기화</button>
                                    </td>
                                    <td>
                                        <button class="btn btn-outline-primary bet-all-max w-100" style="width: 110px;">최대수량</button>
                                    </td>
                                </tr>

                                <tr class="bet-row">
                                    <td></td>
                                    <td>
                                        <button class="btn btn-success btn-bet w-100" data-pick="up">매수신청</button>
                                    </td>
                                    <td>
                                        <button class="btn btn-danger btn-bet w-100" data-pick="down">매도신청</button>
                                    </td>
                                </tr>

                                <tr id="maintenance_alert" class="d-none">
                                    <td colspan="3">
                                        <small class="text-danger"><i class="fas fa-exclamation-triangle"></i> <span>현재 점검으로 인해 거래 서비스를 이용하실 수 없습니다</span></small>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-12 col-md-6">
            <div class="table-responsive mb-3" style="max-height: 400px;">
                <table id="results" class="table table-sm bg-light text-center mb-0">
                    <thead>
                        <tr>
                            <th>회차</th>
                            <th>시가</th>
                            <th>종가</th>
                            <th>결과</th>
                        </tr>
                    </thead>
                    <tbody></tbody>
                </table>
            </div>
        </div>

        <div class="col-12 col-md-6">
            <div class="table-responsive mb-3" style="max-height: 400px;">
                <table class="table table-sm bg-light text-center mb-0">
                    <thead>
                        <tr>
                            <th>시간</th>
                            <th>회차</th>
                            <th>선택</th>
                            <th>결과</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse ($bettings as $betting)
                            <tr>
                                <td>{{ $betting->created_at }}</td>
                                <td>{{ $betting->round }}</td>
                                @if ($betting->pick == 'up')
                                    <td><i class="fas fa-arrow-up text-success"></i> <span>매수</span><small class="d-block">{{ $betting->amount }} LOT</small></td>
                                @else
                                    <td><i class="fas fa-arrow-down text-danger"></i> <span>매도</span><small class="d-block">{{ $betting->amount }} LOT</small></td>
                                @endif

                                @if ($betting->result == 'correct')
                                    <td><i class="far fa-circle text-success"></i> <span>실현</span></td>
                                @elseif ($betting->result == 'incorrect')
                                    <td><i class="fas fa-times text-danger"></i> <span>실격</span></td>
                                @elseif ($betting->result == 'unrealized')
                                    <td><i class="fas fa-undo text-warning"></i> <span>무효</span></td>
                                @else
                                    <td><i class="fas fa-minus text-secondary"></i> <span>대기</span></td>
                                @endif
                            </tr>
                        @empty
                            <tr>
                                <td colspan="4">참여 내역이 없습니다</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>
@endsection
