@extends('layouts.app')

@section('page.name', 'transactions')

@push('scripts')
    <script>
        $(function() {
            if ($('.cleave-phone').length) {
                new Cleave('.cleave-phone', {
                    phone: true,
                    phoneRegionCode: 'KR',
                    delimiter: '-'
                });
            }

            if ($('.amount').length) {
                $.each($('.amount'), function (index, element) {
                    new Cleave(element, {
                        numeral: true,
                        numeralPositiveOnly: true,
                    });
                });
            }
        });
    </script>
@endpush

@section('content')
<div class="container-fluid pt-3">
    <div class="row">
        <div class="col-12 col-lg-6 mb-3">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title">입출금 기록</h5>
                    <table class="table table-sm text-center">
                        <thead>
                            <tr>
                                <th>구분</th>
                                <th>시간</th>
                                <th>금액</th>
                                <th>상태</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($transactions as $transaction)
                                <tr>
                                    @if ($transaction->isDeposit())
                                        <td class="text-primary"><i class="fas fa-plus"></i> 입금</td>
                                    @elseif ($transaction->isWithdraw())
                                        <td class="text-danger"><i class="fas fa-minus"></i> 출금</td>
                                    @endif
                                    <td>{{ $transaction->created_at }}</td>
                                    <td>{{ number_format($transaction->amount) }}</td>
                                    @if ($transaction->isSuccess())
                                        <td><i class="fas fa-check text-success"></i> <span>완료</span></td>
                                    @elseif ($transaction->isFailed())
                                        <td><i class="fas fa-times text-danger"></i> <span>실패</span></td>
                                    @else
                                        <td><i class="fas fa-minus text-secondary"></i> <span>대기</span></td>
                                    @endif
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="4">입출금 기록이 없습니다</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <div class="col-12 col-lg-6">
            @if (Auth::user()->bank_info)
                <div class="card-deck">
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">입금 신청</h5>
                            <p>
                                {!! nl2br(DB::table('config')->where('key', 'deposit_info')->first()->value ?? '') !!}
                            </p>
                            <form action="{{ route('tx.deposit') }}" method="POST" autocomplete="off">
                                @csrf

                                <div class="form-group">
                                    <label>입금계좌</label>
                                    <input type="text" class="form-control form-control-lg" value="{{ DB::table('config')->where('key', 'deposit_bank')->first()->value ?? '1:1 문의로 확인 바랍니다' }}" readonly>
                                </div>

                                <div class="form-group">
                                    <label>신청금액</label>
                                    <input type="text" class="form-control form-control-lg amount" name="amount" inputmode="numeric" required>
                                </div>

                                <button type="submit" class="btn btn-primary">입금 신청</button>
                            </form>
                        </div>
                    </div>

                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">출금 신청</h5>
                            <p>
                                {!! nl2br(DB::table('config')->where('key', 'withdraw_info')->first()->value ?? '') !!}
                            </p>

                            <form action="{{ route('tx.withdraw') }}" method="POST" autocomplete="off">
                                @csrf

                                <div class="form-group">
                                    <label>신청금액</label>
                                    <input type="text" class="form-control form-control-lg amount" name="amount" inputmode="numeric" required>
                                    <small class="form-text text-muted">출금 가능금액: {{ number_format(Auth::user()->balance) }} 원</small>
                                </div>

                                <button type="submit" class="btn btn-danger">출금 신청</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        @else
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title">계좌 정보 등록</h5>
                    <ul>
                        <li>입/출금을 하기 전 먼저 계좌 정보를 등록해야 합니다</li>
                    </ul>

                    <form action="{{ route('tx.bank_info.update') }}" method="POST" autocomplete="off">
                        @csrf
                        @method('PATCH')

                        <div class="form-group">
                            <label>은행명</label>
                            <input type="text" class="form-control form-control-lg" name="bank_name" required>
                        </div>

                        <div class="form-group">
                            <label>계좌번호</label>
                            <input type="text" class="form-control form-control-lg" name="bank_address" inputmode="numeric" required>
                        </div>

                        <div class="form-group">
                            <label>예금주</label>
                            <input type="text" class="form-control form-control-lg" name="bank_owner" required>
                        </div>

                        <div class="form-group">
                            <label>전화번호</label>
                            <input type="text" class="form-control form-control-lg cleave-phone" name="contact" inputmode="numeric" required>
                        </div>

                        <button type="submit" class="btn btn-success">계좌 등록</button>
                    </form>
                </div>
            </div>
        @endif
    </div>
</div>
@endsection
