<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::domain('udf.bitqzone.com')->group(function () {
    Route::get('/config', 'ChartController@getConfig');
    Route::get('/time', 'ChartController@getTime');
    Route::get('/symbol_info', 'ChartController@getSymbolInfo');
    Route::get('/symbols', 'ChartController@getSymbols');
    Route::get('/history', 'ChartController@getHistory');
});

Route::domain('admin.bitqzone.com')->group(function () {
    Route::redirect('/', '/main')->name('main');

    Route::name('branch.')->group(function () {
        Auth::routes();

        Route::get('/main', 'BranchController@index')->name('main');

        Route::get('/branches', 'BranchController@listBranch')->name('branch.list');
        Route::post('/branches', 'BranchController@createBranch')->name('branch.create');
        Route::get('/branches/{user}', 'BranchController@getBranch')->name('branch.show');
        Route::patch('/branches/{user}', 'BranchController@modifyBranch')->name('branch.modify');
        Route::get('/branches/{user}/overview', 'BranchController@index')->name('branch.main');
        Route::get('/branches/{user}/users', 'BranchController@listUser')->name('branch.user.list');
        Route::get('/branches/{user}/users.dt', 'BranchController@listUserDT')->name('branch.user.list.datatable');
        Route::get('/branches/{user}/trades', 'BranchController@listTrade')->name('branch.trade.list');
        Route::get('/branches/{user}/transactions', 'BranchController@listTransaction')->name('branch.tx.list');

        Route::get('/users', 'BranchController@listUser')->name('user.list');
        Route::get('/users.dt', 'BranchController@listUserDT')->name('user.list.datatable');
        Route::get('/users/{user}', 'BranchController@getUser')->name('user.show');
        Route::patch('/users/{user}', 'BranchController@updateUser')->name('user.update');
        Route::get('/users/{user}/trades', 'BranchController@listTrade')->name('user.trade.list');
        Route::get('/users/{user}/transactions', 'BranchController@listTransaction')->name('user.tx.list');
        Route::get('/users/{user}/transactions.dt', 'BranchController@listTransactionDT')->name('user.tx.list.datatable');
        Route::get('/trades', 'BranchController@listTrade')->name('trade.list');
        Route::get('/transactions', 'BranchController@listTransaction')->name('tx.list');
        Route::get('/transactions.dt', 'BranchController@listTransactionDT')->name('tx.list.datatable');
        Route::patch('/transactions/{transaction}', 'BranchController@updateTransaction')->name('tx.update');

        Route::get('/fee_transactions', 'BranchController@listFeeTransaction')->name('fee_tx.list');
        Route::patch('/fee_transactions/{fee_transaction}', 'BranchController@updateFeeTransaction')->name('fee_tx.update');

        Route::post('/withdraw_fee', 'BranchController@withdrawFee')->name('withdraw_fee');
        Route::patch('/user/bank_info', 'TxController@updateBankInfo')->name('tx.bank_info.update');

        Route::get('/trades/waiting', 'BranchController@listWaitingTrades')->name('trade.waiting.list');
        Route::get('/trades/waiting.json', 'BranchController@listWaitingTradesJson')->name('trade.waiting.list.json');
        Route::get('/trades/unplayed', 'BranchController@listUnplayedTrades')->name('trade.unplayed.list');
        Route::post('/trades', 'BranchController@createGameResult')->name('trade.create');

        Route::get('/contacts', 'ContactController@listAdmin')->name('contact.list');
        Route::get('/contacts.dt', 'ContactController@listAdminDT')->name('contact.list.datatable');
        Route::get('/contacts/{contact}', 'ContactController@showAdmin')->name('contact.show');
        Route::post('/contacts/{contact}', 'ContactController@reply')->name('contact.reply');
        Route::delete('/contacts/{contact}', 'ContactController@delete')->name('contact.delete');

        Route::get('/notices', 'NoticeController@listBranch')->name('notice.list');
        Route::get('/notices/new', 'NoticeController@showForm')->name('notice.form');
        Route::get('/notices/{notice}', 'NoticeController@showForm')->name('notice.modify');
        Route::post('/notices', 'NoticeController@create')->name('notice.create');
        Route::patch('/notices/{notice}', 'NoticeController@update')->name('notice.update');

        Route::get('/notes/new', 'NoteController@showForm')->name('note.form');
        Route::post('/notes', 'NoteController@sendNote')->name('note.create');

        Route::get('/popups/new', 'PopupController@showForm')->name('popup.form');
        Route::post('/popups', 'PopupController@create')->name('popup.create');

        Route::get('/config', 'BranchController@getConfig')->name('config.get');
        Route::patch('/config', 'BranchController@setConfig')->name('config.update');

        Route::get('/new_request.json', 'BranchController@getNewRequest')->name('new_request.json');
    });
});

Route::domain('bitqzone.com')->group(function () {
    Route::get('/', 'MainController@index')->name('main');

    Auth::routes();
    Route::get('/password/change', 'Auth\ChangePasswordController@showChangeForm')->name('password.change');
    Route::patch('/password', 'Auth\ChangePasswordController@changePassword')->name('password.update');

    Route::get('/trade/{symbol}/{minutes}.json', 'TradeController@info')->name('trade.info');
    Route::get('/trade/{symbol}/{minutes?}', 'TradeController@index')->name('trade.index');
    Route::post('/trade/{symbol}/{minutes}', 'TradeController@betGame')->name('trade.bet');
    Route::get('/trades/{symbol}/{minutes}.json', 'TradeController@listGameResultJson')->name('trade.results.json');
    Route::get('/trades/{minutes?}', 'TradeController@listTrades')->name('trade.list');

    Route::get('/transactions', 'TxController@index')->name('tx.index');
    Route::post('/transactions/deposit', 'TxController@deposit')->name('tx.deposit');
    Route::post('/transactions/withdraw', 'TxController@withdraw')->name('tx.withdraw');
    Route::patch('/user/bank_info', 'TxController@updateBankInfo')->name('tx.bank_info.update');

    Route::get('/contacts', 'ContactController@list')->name('contact.list');
    Route::post('/contacts', 'ContactController@create')->name('contact.create')->middleware('throttle:1,1');
    Route::get('/contacts/{contact}', 'ContactController@show')->name('contact.show');

    Route::get('/notices/{notice?}', 'NoticeController@list')->name('notice.list');
    Route::delete('/notices/{notice}', 'NoticeController@delete')->name('notice.delete');

    Route::get('/notes', 'NoteController@list')->name('note.list');
    Route::get('/notes/{note}', 'NoteController@show')->name('note.show');

    Route::prefix('dashboard')->name('branch.')->group(function () {
        Route::get('/', 'BranchController@index')->name('main');

        Route::get('/branches', 'BranchController@listBranch')->name('branch.list');
        Route::post('/branches', 'BranchController@createBranch')->name('branch.create');
        Route::get('/branches/{user}', 'BranchController@getBranch')->name('branch.show');
        Route::patch('/branches/{user}', 'BranchController@modifyBranch')->name('branch.modify');
        Route::get('/branches/{user}/overview', 'BranchController@index')->name('branch.main');
        Route::get('/branches/{user}/users', 'BranchController@listUser')->name('branch.user.list');
        Route::get('/branches/{user}/users.dt', 'BranchController@listUserDT')->name('branch.user.list.datatable');
        Route::get('/branches/{user}/trades', 'BranchController@listTrade')->name('branch.trade.list');
        Route::get('/branches/{user}/transactions', 'BranchController@listTransaction')->name('branch.tx.list');

        Route::get('/users', 'BranchController@listUser')->name('user.list');
        Route::get('/users.dt', 'BranchController@listUserDT')->name('user.list.datatable');
        Route::get('/users/{user}', 'BranchController@getUser')->name('user.show');
        Route::patch('/users/{user}', 'BranchController@updateUser')->name('user.update');
        Route::get('/users/{user}/trades', 'BranchController@listTrade')->name('user.trade.list');
        Route::get('/users/{user}/transactions', 'BranchController@listTransaction')->name('user.tx.list');
        Route::get('/users/{user}/transactions.dt', 'BranchController@listTransactionDT')->name('user.tx.list.datatable');
        Route::get('/trades', 'BranchController@listTrade')->name('trade.list');
        Route::get('/transactions', 'BranchController@listTransaction')->name('tx.list');
        Route::get('/transactions.dt', 'BranchController@listTransactionDT')->name('tx.list.datatable');
        Route::patch('/transactions/{transaction}', 'BranchController@updateTransaction')->name('tx.update');

        Route::get('/fee_transactions', 'BranchController@listFeeTransaction')->name('fee_tx.list');
        Route::patch('/fee_transactions/{fee_transaction}', 'BranchController@updateFeeTransaction')->name('fee_tx.update');

        Route::post('/withdraw_fee', 'BranchController@withdrawFee')->name('withdraw_fee');
        Route::patch('/user/bank_info', 'TxController@updateBankInfo')->name('tx.bank_info.update');

        Route::get('/trades/waiting', 'BranchController@listWaitingTrades')->name('trade.waiting.list');
        Route::get('/trades/waiting.json', 'BranchController@listWaitingTradesJson')->name('trade.waiting.list.json');
        Route::get('/trades/unplayed', 'BranchController@listUnplayedTrades')->name('trade.unplayed.list');
        Route::post('/trades', 'BranchController@createGameResult')->name('trade.create');

        Route::get('/contacts', 'ContactController@listAdmin')->name('contact.list');
        Route::get('/contacts.dt', 'ContactController@listAdminDT')->name('contact.list.datatable');
        Route::get('/contacts/{contact}', 'ContactController@showAdmin')->name('contact.show');
        Route::post('/contacts/{contact}', 'ContactController@reply')->name('contact.reply');
        Route::delete('/contacts/{contact}', 'ContactController@delete')->name('contact.delete');

        Route::get('/notices', 'NoticeController@listBranch')->name('notice.list');
        Route::get('/notices/new', 'NoticeController@showForm')->name('notice.form');
        Route::get('/notices/{notice}', 'NoticeController@showForm')->name('notice.modify');
        Route::post('/notices', 'NoticeController@create')->name('notice.create');
        Route::patch('/notices/{notice}', 'NoticeController@update')->name('notice.update');

        Route::get('/notes/new', 'NoteController@showForm')->name('note.form');
        Route::post('/notes', 'NoteController@sendNote')->name('note.create');

        Route::get('/popups/new', 'PopupController@showForm')->name('popup.form');
        Route::post('/popups', 'PopupController@create')->name('popup.create');

        Route::get('/config', 'BranchController@getConfig')->name('config.get');
        Route::patch('/config', 'BranchController@setConfig')->name('config.update');

        Route::get('/new_request.json', 'BranchController@getNewRequest')->name('new_request.json');
    });
});

Route::get('/', function () {
    return '<div style="font-size: 3em; text-align: center;"><h1>도메인 변경 안내</h1><p>도메인이 변경되어 변경된 주소로 접속 바랍니다</p><a href="https://bitqzone.com">https://bitqzone.com</a></div>';
});
